@@ -1,19 +1,17 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
-#include <QWebView>
+#include <QWebEngineView>
 
 #ifndef _BROWSER_H
 #define _BROWSER_H
 
 class QMenu;
-class browser: public QWebView
+class browser: public QWebEngineView
 {
 	Q_OBJECT
 	public:
 		browser(QWidget*);
 		void contextMenuEvent(QContextMenuEvent * event);
-	public slots:
-		void toggleFullScreen();
 	private:
 		QMenu * m_oMenu;
 };
