@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 
 #include <QGraphicsScene>
@@ -24,7 +24,7 @@
 canvas_flag::canvas_flag(canvas_view *i_oGraphWidget, canvas_item *i_oFrom)
 	: QGraphicsRectItem(), m_oGraph(i_oGraphWidget)
 {
-	setFlags(ItemIsMovable & ItemIsSelectable);
+	setFlags(NULL);
 	m_oItem = i_oFrom;
 	setRect(0, 0, 19, 19);
 
@@ -33,7 +33,6 @@ canvas_flag::canvas_flag(canvas_view *i_oGraphWidget, canvas_item *i_oFrom)
 
 	i_oGraphWidget->scene()->addItem(this);
 	setParentItem(m_oItem);
-	setCacheMode(QGraphicsItem::DeviceCoordinateCache);
 }
 
 void canvas_flag::paint(QPainter *i_oPainter, const QStyleOptionGraphicsItem *i_oOption, QWidget * i_oW)
@@ -43,22 +42,18 @@ void canvas_flag::paint(QPainter *i_oPainter, const QStyleOptionGraphicsItem *i_
 	{
 		if (this == m_oItem->m_oFlags[i]) { l_iIndex = i; break; }
 	}
-	data_item *l_oDataItem = m_oGraph->m_oMediator->m_oItems.value(m_oItem->Id());
-	QString l_sName = l_oDataItem->m_oFlags[l_iIndex];
+	data_item& l_oDataItem = m_oGraph->m_oMediator->m_oItems[m_oItem->Id()];
+	QString l_sName = l_oDataItem.m_oFlags[l_iIndex];
 
 	for (int i=0; i<m_oGraph->m_oMediator->m_oFlagSchemes.size(); ++i)
 	{
-		if (m_oGraph->m_oMediator->m_oFlagSchemes[i]->m_sId == l_sName)
+		flag_scheme &l_oFlag = m_oGraph->m_oMediator->m_oFlagSchemes[i];
+		if (l_oFlag.m_sId == l_sName)
 		{
-			QSvgRenderer *l_o = m_oGraph->m_oMediator->m_oFlagSchemes[i]->_renderer();
+			QSvgRenderer *l_o = l_oFlag._renderer();
 			l_o->render(i_oPainter, boundingRect());
 			break;
 		}
 	}
 }
 
-#ifdef WAF
-#else
-#include "canvas_view.moc"
-#endif
-
