@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 
 
@@ -23,6 +23,7 @@ class canvas_link;
 class canvas_sort;
 class canvas_flag;
 class canvas_chain;
+class canvas_pic;
 class canvas_sort_toggle;
 
 class canvas_item: public QGraphicsTextItem
@@ -58,6 +59,16 @@ class canvas_item: public QGraphicsTextItem
 
 		int Id() const {return m_iId;};
 
+		double m_dRadius;
+		double m_dPosX;
+		double m_dPosY;
+		double m_dSpeedX;
+		double m_dSpeedY;
+		double m_dForceX;
+		double m_dForceY;
+		double m_dWW2;
+		double m_dHH2;
+
 		bool m_bEdit;
 		int m_iNum;
 
@@ -82,11 +93,14 @@ class canvas_item: public QGraphicsTextItem
 		inline qreal const x2() {return x() + boundingRect().width();}
 		inline qreal const y2() {return y() + boundingRect().height();}
 
+		qreal reorgHeight();
+
 		canvas_view *m_oGraph;
 		canvas_item *m_oParent;
 		canvas_sort *m_oSort;
 		canvas_chain *m_oChain;
 		canvas_sort_toggle *m_oSortToggle;
+		 canvas_pic*  m_oPic;
 
 		int m_iId;
 		QColor m_oColor;
