@@ -1,8 +1,9 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef CON
 #define CON
 
+#include <KLocalizedString>
 #include <QtGlobal>
 #include <QHash>
 #include <QVariant>
@@ -11,11 +12,13 @@
 #define gratype(x) (QGraphicsItem::UserType + x)
 #define CANVAS_ITEM_T gratype(12301)
 #define CANVAS_FLAG_T gratype(12302)
+#define  CANVAS_PIC_T gratype(12308)
 #define CANVAS_LINK_T gratype(12303)
 #define CANVAS_SORT_T gratype(12304)
 #define BOX_ITEM_T gratype(12305)
 #define BOX_LINK_T gratype(12306)
 #define CANVAS_CHAIN_T gratype(12307)
+#define CANVAS_REF_T gratype(12309)
 
 #define hash_params QHash<int, QVariant>
 
@@ -27,7 +30,6 @@
 #define data_commande 5
 #define data_type 6 // change the view stuff
 
-
 #define VIEW_CANVAS 1
 #define VIEW_LINEAR 2
 #define VIEW_TEXT 3
@@ -36,9 +38,9 @@
 #define VIEW_TABLE 6
 
 
-#define notr(x) QString(x)
-#define xp(a, b, d) a->setItem(b, 0, new QStandardItem(d));
-#define yp(a, b, d) a->setItem(b, 1, new QStandardItem(d));
+#define notr(x) (QString(x))
+#define xxp(a, b, d) a->setItem(b, 0, new QStandardItem(d));
+#define yyp(a, b, d) a->setItem(b, 1, new QStandardItem(d));
 
 
 #define GRID 10
@@ -48,7 +50,7 @@
 
 
 int grid_int(int x);
-
+int fceil(qreal l_fInput, int l_iBase);
 
 
 #define mu(x)   #x
