@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QtDebug>
 #include <QLabel>
@@ -14,7 +14,7 @@ data_view::data_view(QWidget *i_oParent, sem_mediator *i_oControl) : QStackedWid
 	m_oMediator = i_oControl;
 
 	m_oLabel = new QLabel(this);
-	m_oLabel->setText(trUtf8("<p align='center'>No item selected</p>"));
+	m_oLabel->setText(i18n("<p align='center'>No item selected</p>"));
 	addWidget(m_oLabel);
 }
 
@@ -29,9 +29,9 @@ void data_view::notify_select(const QList<int>& unsel, const QList<int>& sel) {
 }
 
 void data_view::notify_datatype(int id) {
-	data_item *l_oItem = *m_oMediator + id;
+	data_item& l_oItem = *m_oMediator + id;
 	int j = 0;
-	switch (l_oItem->m_iDataType)
+	switch (l_oItem.m_iDataType)
 	{
 		// text image table diagram
 		case VIEW_DIAG: j++;
@@ -45,5 +45,3 @@ void data_view::notify_datatype(int id) {
 	}
 }
 
-#include "data_view.moc"
-
