@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef BOX_ACTOR_H
 #define BOX_ACTOR_H
@@ -13,11 +13,16 @@
 
 #define OFF 3
 
+class QGraphicsTextItem;
 class box_actor : public box_item
 {
 	public:
 		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
 		box_actor(box_view*, int i_iId);
+		~box_actor();
+		QGraphicsTextItem *m_oCaption;
+		void update_size();
+		void update_links();
 };
 
 #endif // BOX_ACTOR_H
