@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QApplication>
 #include <QPainter>
@@ -21,7 +21,7 @@ void box_chain::paint(QPainter *i_oPainter, const QStyleOptionGraphicsItem *opti
 {
         QPen l_oPen(Qt::SolidLine);
 	l_oPen.setColor(Qt::black);
-	l_oPen.setWidth(1);
+	l_oPen.setWidthF(0.01 + 1);
 	i_oPainter->setPen(l_oPen);
 
 	i_oPainter->drawLine(QPoint(PAD, 5), QPoint(10-PAD, 5));
