@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 
 #ifndef BOX_DOT_H
@@ -25,11 +25,11 @@ class box_dot : public QGraphicsRectItem, public connectable
 
 		//QRectF boundingRect() const;
 
-		QRectF rect() const { return boundingRect().translated(pos()).adjusted(JUST, JUST, -JUST, -JUST); };
+		QRectF rectPos() const { return QGraphicsRectItem::rect().translated(pos()); };
 		//void setRect(int, int, int, int) { }
 
 		box_view *m_oView;
-		data_item *m_oItem;
+		data_item& m_oItem;
 
 		void mousePressEvent(QGraphicsSceneMouseEvent* e);
 		void mouseReleaseEvent(QGraphicsSceneMouseEvent* e);
@@ -41,7 +41,7 @@ class box_dot : public QGraphicsRectItem, public connectable
 		void update_size();
 
 		QVariant itemChange(GraphicsItemChange i_oChange, const QVariant &i_oValue);
-		int choose_position(const QPointF&p, int id=-1);
+		int choose_position(const QPointF&p, box_link*, box_control_point*);
 		QPoint get_point(int position);
 
 };
