@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef BOX_FORK_H
 #define BOX_FORK_H
@@ -25,10 +25,10 @@ class box_fork : public QGraphicsRectItem, public connectable, public resizable
 
 		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
 
-		QRectF rect() const { return boundingRect().translated(pos()).adjusted(JUST, JUST, -JUST, -JUST); };
+		QRectF rectPos() const { return QGraphicsRectItem::rect().translated(pos()); };
 
 		box_view *m_oView;
-		data_item *m_oItem;
+		data_item& m_oItem;
 
 		void mousePressEvent(QGraphicsSceneMouseEvent* e);
 		void mouseReleaseEvent(QGraphicsSceneMouseEvent* e);
@@ -42,7 +42,7 @@ class box_fork : public QGraphicsRectItem, public connectable, public resizable
 		box_resize_point *m_oRight;
 
 		QVariant itemChange(GraphicsItemChange i_oChange, const QVariant &i_oValue);
-		int choose_position(const QPointF&p, int id=-1);
+		int choose_position(const QPointF&p, box_link*, box_control_point*);
 		QPoint get_point(int position);
 
 		void update_sizers();
