@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QApplication>
 #include <QAbstractTextDocumentLayout>
@@ -23,7 +23,6 @@
 
 #include <QFont>
 
-#define PAD 2
 #define MIN_FORK_SIZE 30
 
 box_node::box_node(box_view* view, int id) : box_item(view, id)
@@ -32,34 +31,31 @@ box_node::box_node(box_view* view, int id) : box_item(view, id)
 	font.setBold(true);
 	doc.setDefaultFont(font);
 
+	// FIXME move the resize handle by x-10
 	setZValue(90);
+	x_text_off = 2 * OFF + 20;
+	y_text_off = 2 * OFF + 30;
 }
 
 void box_node::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-	painter->save();
-
-	QRectF l_oRect = boundingRect().adjusted(PAD, PAD, -PAD, -PAD);
-
-	QColor bc(m_oBox->color);
-	if (m_oView->m_bDisableGradient)
-	{
-		painter->setBrush(bc);
-	}
-	else
-	{
-		QLinearGradient linearGradient(0, 0, l_oRect.width(), 0);
-		linearGradient.setColorAt(0.0, bc);
-		linearGradient.setColorAt(1.0, bc.darker(GRADVAL));
-		painter->setBrush(linearGradient);
-	}
+	doc.setDefaultFont(scene()->font());
+	QTextOption l_oOption = doc.defaultTextOption();
+	l_oOption.setAlignment(m_oBox->m_iAlign);
+	doc.setDefaultTextOption(l_oOption);
 
 
+	QColor bc = m_oBox->getColor(m_oView->m_oMediator);
+	painter->setBrush(bc);
 
 	QPen l_oPen = QPen(Qt::SolidLine);
 	l_oPen.setColor(Qt::black);
 	l_oPen.setCosmetic(false);
-	l_oPen.setWidth(1);
+	l_oPen.setWidthF(0.01 + 1);
+	qreal pad = l_oPen.widthF() / 2.;
+	QRectF l_oRect = rect().adjusted(pad, pad, -pad, -pad);
+
+
 	if (isSelected())
 	{
 		l_oPen.setStyle(Qt::DotLine);
@@ -69,6 +65,9 @@ void box_node::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
 	QRectF br = l_oRect.adjusted(0, 10, -10, 0);
 	painter->drawRect(br);
 
+
+	painter->setBrush(bc.lighter(GRADVAL));
+
 	QPointF pts[4];
 	pts[0] = br.topLeft();
 	pts[1] = br.topLeft() + QPointF(10, -10);
@@ -77,6 +76,8 @@ void box_node::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
 
 	painter->drawPolygon(pts, 4);
 
+	painter->setBrush(bc.darker(GRADVAL));
+
 	pts[0] = br.topRight();
 	pts[1] = br.topRight() + QPointF(10, -10);
 	pts[2] = br.bottomRight() + QPointF(10, -10);
@@ -84,32 +85,12 @@ void box_node::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
 
 	painter->drawPolygon(pts, 4);
 
-	if (isSelected())
-	{
-		l_oPen.setStyle(Qt::SolidLine);
-		painter->setPen(l_oPen);
-		painter->setBrush(QColor("#FFFF00"));
-		QRectF l_oR2(m_iWW - 10 - 8, m_iHH - 8, 6, 6);
-		painter->drawRect(l_oR2);
-	}
-
-	painter->translate(OFF, OFF + 10);
+	painter->translate((rect().width() - 10 - doc.size().width())/2, OFF + 10);
 	QAbstractTextDocumentLayout::PaintContext ctx;
 	ctx.palette = QApplication::palette("QTextControl");
 	ctx.palette.setColor(QPalette::Text, Qt::black); // white on black kde themes
+
 	doc.documentLayout()->draw(painter, ctx);
-
-	painter->restore();
-}
-
-void box_node::update_size() {
-	m_iWW = m_oBox->m_iWW;
-	m_iHH = m_oBox->m_iHH;
-
-	doc.setHtml(QString("<div align='center'>%1</div>").arg(m_oBox->m_sText));
-	doc.setTextWidth(m_iWW - 2 * OFF - 20);
-
-	setRect(0, 0, m_iWW, m_iHH);
 }
 
 void box_node::mousePressEvent(QGraphicsSceneMouseEvent* e)
@@ -118,9 +99,10 @@ void box_node::mousePressEvent(QGraphicsSceneMouseEvent* e)
 	if (m_oLastPressPoint.x() > m_iWW - GRID - 10 && m_oLastPressPoint.x() < m_iWW - 10 && m_oLastPressPoint.y() > m_iHH - GRID)
 	{
 		setFlags(ItemIsSelectable | ItemSendsGeometryChanges);
-		m_bMoving = true;
 	}
 	QGraphicsRectItem::mousePressEvent(e);
 }
 
-
+QSize box_node::best_size(const QPointF &dims) {
+	return box_item::best_size(dims).expandedTo(QSize(30, 30));
+}
