@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef BOX_NODE_H
 #define BOX_NODE_H
@@ -18,8 +18,8 @@ class box_node : public box_item
 	public:
 		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
 		box_node(box_view*, int i_iId);
-		void update_size();
 		void mousePressEvent(QGraphicsSceneMouseEvent* e);
+		QSize best_size(const QPointF &dims);
 };
 
 #endif // BOX_NODE_H
