@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef BOX_RESIZE_H
 #define BOX_RESIZE_H
@@ -21,6 +21,7 @@ class box_resize_point : public QGraphicsRectItem
 		bool m_bMoveX;
 
 		int m_iPosition;
+		int m_iOriginalSize; // matrix
 		box_view *m_oView;
 		resizable *m_oParent;
 
@@ -34,7 +35,6 @@ class box_resize_point : public QGraphicsRectItem
 		bool m_bHeld;
 
 	private:
-		bool m_bChanged;
 		bool m_bForced;
 
 };
