@@ -1,15 +1,18 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 
 #ifndef BOX_VIEW_H
 #define BOX_VIEW_H
 
+#include <QUrl>
 #include <QGraphicsView>
 #include <QList>
 #include <QPoint>
+#include "data_item.h"
 #include "con.h"
 
 class QActionGroup;
+class QMenu;
 class connectable;
 class box_item;
 class box_link;
@@ -44,13 +47,18 @@ class box_view : public QGraphicsView
 		//QMenu* m_oWidthMenu;
 		//QMenu* m_oStyleMenu;
 		QMenu* m_oAddBoxMenu;
+		QMenu* m_oTextAlignMenu;
 		QMenu* m_oAlignMenu;
 		QMenu* m_oSizeMenu;
+		QMenu* m_oFileMenu;
+		QMenu* m_oColorMenu;
 
 		QAction *m_oAddItemAction;
 		QAction *m_oAddLabel;
 		QAction *m_oAddComponent;
+		QAction *m_oAddRectangle;
 		QAction *m_oAddActor;
+		QAction *m_oAddCloud;
 		QAction *m_oAddUsecase;
 		QAction *m_oAddNode;
 		QAction *m_oAddDotStart;
@@ -58,6 +66,16 @@ class box_view : public QGraphicsView
 		QAction *m_oAddDecision;
 		QAction *m_oAddParallelHorizontal;
 		QAction *m_oAddParallelVertical;
+		QAction *m_oAddMatrix;
+		QAction *m_oAddFrame;
+		QAction *m_oAddClass;
+		QAction *m_oAddEntity;
+		QAction *m_oAddDatabase;
+		QAction *m_oAddSequence;
+		QAction *m_oAddPipe;
+		QAction *m_oFileExport;
+		QAction *m_oFileImport;
+		QAction *m_oCopyToClipboard;
 
 		QAction *m_oPropertiesAction;
 		QAction *m_oDeleteAction;
@@ -74,6 +92,7 @@ class box_view : public QGraphicsView
 
 		void sync_view();
 		void from_string(const QString &);
+		void resizeEvent(QResizeEvent*);
 
 		sem_mediator *m_oMediator;
 
@@ -83,6 +102,7 @@ class box_view : public QGraphicsView
 
 		QActionGroup *m_oWidthGroup;
 		QActionGroup *m_oStyleGroup;
+		QActionGroup *m_oTextAlignGroup;
 		QActionGroup *m_oAlignGroup;
 		QActionGroup *m_oSizeGroup;
 
@@ -97,19 +117,29 @@ class box_view : public QGraphicsView
 
 		//void edit_off();
 
-		int next_seq();
-		int num_seq;
+		const QPixmap getPix(int i_iId);
+		QRectF drawThumb(QPainter* i_oPainter, QRectF& l_o, int m_iId);
 
 		void message(const QString &, int);
 		bool m_bDisableGradient;
+		bool m_bShowFileMenu;
+		void init_menu();
+		QUrl m_oCurrentUrl;
+
+		int batch_print_map(const QUrl& i_oUrl, QPair<int, int> & p);
+		bool import_from_file(const QUrl& l_o);
+		void export_fig_size();
+		void insert_diagram();
+		QRectF visibleRect();
 
 	public slots:
 		void change_colors(QAction* i_oAct);
 		void enable_actions(); // used on focus in
+		void fit_zoom();
 		void slot_delete();
 		void slot_add_item();
-		void slot_color();
 		void slot_edit_properties();
+		void slot_text_align();
 		void slot_align();
 		void slot_size();
 
@@ -120,6 +150,7 @@ class box_view : public QGraphicsView
 		void slot_penwidth();
 
 		void slot_add_element();
+		void slot_print();
 
 		void notify_focus(void* ptr);
 		void notify_add_item(int);
@@ -131,13 +162,22 @@ class box_view : public QGraphicsView
 		void notify_box_props(int id, const QList<diagram_item*>&);
 		void notify_pos_box(int, const QList<data_box*>&);
 		void notify_size_box(int, const QList<data_box*>&);
+		void notify_text_align(int, const QList<data_box>&);
 		void notify_change_link_box(int id, data_link*link);
+		void notify_change_properties(void *);
+		void notify_sequence_box(int, int);
 
 		void notify_select(const QList<int>& unsel, const QList<int>& sel);
 		void notify_export_item(int);
 
+		bool slot_import_from_file();
+		bool slot_export_to_file();
+		bool slot_save();
+		void slot_copy_picture();
+
 	signals:
 		void sig_message(const QString &, int);
+		void sig_Url(const QUrl&);
 };
 
 #endif
