@@ -1,10 +1,10 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QVariant>
 #include <QAction>
 #include <QApplication>
 #include <QButtonGroup>
-#include <KDialog>
+#include <KDE/KDialog>
 #include <QGridLayout>
 #include<QPushButton>
 #include <QLabel>
@@ -27,16 +27,16 @@ generator_dialog::generator_dialog(QWidget *i_oParent, QList<template_entry> i_o
 	m_oLst(i_oLst)
 {
 	QWidget *widget = new QWidget(this);
-	setCaption(trUtf8("Generate documents"));
+	setCaption(i18n("Generate documents"));
 	setButtons(KDialog::Ok | KDialog::Cancel);
 
 	QGridLayout *l_oGridLayout = new QGridLayout(widget);
 
 	QLabel *label = new QLabel(widget);
-	label->setText(trUtf8("Generators"));
+	label->setText(i18n("Generators"));
 
 	QLabel *label2 = new QLabel(widget);
-	label2->setText(trUtf8("Description"));
+	label2->setText(i18n("Description"));
 
 	l_oGridLayout->addWidget(label, 0, 0, 1, 2);
 	l_oGridLayout->addWidget(label2, 0, 2, 1, 1);
@@ -44,7 +44,6 @@ generator_dialog::generator_dialog(QWidget *i_oParent, QList<template_entry> i_o
 	m_oTree = new QTreeWidget(widget);
 	m_oTree->header()->hide();
 	l_oGridLayout->addWidget(m_oTree, 1, 0, 1, 2);
-	m_oTree->setFocusPolicy(Qt::NoFocus);
 
 	m_oTextEdit = new QTextEdit(widget);
 	m_oTextEdit->setReadOnly(true);
@@ -53,14 +52,14 @@ generator_dialog::generator_dialog(QWidget *i_oParent, QList<template_entry> i_o
 
 
 	label = new QLabel(widget);
-	label->setText(trUtf8("Name"));
+	label->setText(i18n("Name"));
 	l_oGridLayout->addWidget(label, 2, 0, 1, 1);
 
 	m_oName = new QLineEdit(widget);
 	l_oGridLayout->addWidget(m_oName, 2, 1, 1, 2);
 
 	label = new QLabel(widget);
-	label->setText(trUtf8("Location"));
+	label->setText(i18n("Location"));
 	l_oGridLayout->addWidget(label, 3, 0, 1, 1);
 
 	m_oLocation = new QLineEdit(widget);
@@ -81,27 +80,29 @@ generator_dialog::generator_dialog(QWidget *i_oParent, QList<template_entry> i_o
 		l_oItem->setData(0, Qt::UserRole+4, l_o.m_sTip);
 	}
 
-	connect(m_oTree, SIGNAL(itemClicked(QTreeWidgetItem *, int)), this, SLOT(selection_changed(QTreeWidgetItem *, int)));
-
+	connect(m_oTree, SIGNAL(itemSelectionChanged()), this, SLOT(selection_changed()));
+	
 
    	setMainWidget(widget);
-
+	m_oTree->setFocus();
 	QSize size(421, 250);
 	size = size.expandedTo(minimumSizeHint());
 	resize(size);
 }
 
-void generator_dialog::selection_changed(QTreeWidgetItem * i_oItem, int i_oCol)
+void generator_dialog::selection_changed()
 {
-	if (!i_oItem)
+	QList<QTreeWidgetItem*> l_oSel = m_oTree->selectedItems();
+	if (l_oSel.isEmpty())
 	{
 		m_oTextEdit->clear();
 	}
 	else
 	{
-		m_oTextEdit->setText(i_oItem->data(0, Qt::UserRole+4).toString());
-		m_sCurrent = i_oItem->data(0, Qt::UserRole+3).toString();
-		m_sShortName = i_oItem->text(0);
+		QTreeWidgetItem *l_oItem = l_oSel.at(0);
+		m_oTextEdit->setText(l_oItem->data(0, Qt::UserRole+4).toString());
+		m_sCurrent = l_oItem->data(0, Qt::UserRole+3).toString();
+		m_sShortName = l_oItem->text(0);
 	}
 
 }
@@ -111,13 +112,13 @@ void generator_dialog::slotButtonClicked(int button) {
 	{
 		if (m_sCurrent.length()<2)
 		{
-			KMessageBox::sorry(this, trUtf8("No document generator chosen."), trUtf8("Missing data"));
+			KMessageBox::sorry(this, i18n("No document generator chosen."), i18n("Missing data"));
 			return;
 		}
 		QFileInfo l_oFi(m_oLocation->text());
 		if (!l_oFi.isDir() || !l_oFi.isWritable())
 		{
-			KMessageBox::sorry(this, trUtf8("Invalid output directory %1").arg(m_oLocation->text()), trUtf8("Missing location"));
+			KMessageBox::sorry(this, i18n("Invalid output directory %1", m_oLocation->text()), i18n("Missing location"));
 			return;
 		}
 		accept();
@@ -135,8 +136,6 @@ void generator_dialog::activate_from_name(const QString &i_s)
 	{
 		m_sShortName = i_s;
 		m_oTree->setCurrentItem(l_o[0]);
-		selection_changed(l_o[0], 0);
 	}
 }
 
-#include "generator_dialog.moc"
