@@ -1,9 +1,9 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef GENERATOR_DIALOG_H
 #define GENERATOR_DIALOG_H
 
-#include <KDialog>
+#include <KDE/KDialog>
 
 #include "con.h"
 #include "template_entry.h"
@@ -11,6 +11,7 @@
 class QLineEdit;
 class QTextEdit;
 class QTreeWidgetItem;
+class QTreeWidget;
 class generator_dialog : public KDialog
 {
 	Q_OBJECT
@@ -25,7 +26,7 @@ class generator_dialog : public KDialog
 		QString m_sShortName;
 
 	public slots:
-		void selection_changed(QTreeWidgetItem *i_o, int i_oCol);
+		void selection_changed();
 		void slotButtonClicked(int button);
 		void activate_from_name(const QString &i_s);
 };
