@@ -1,14 +1,15 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QPainter>
-#include  <QToolTip>
+#include <QToolTip>
 #include <QtDebug>
-#include	<QHelpEvent>
+#include <QHelpEvent>
 #include <QLabel>
 #include <QMenu>
 #include <QList>
 #include <QFile>
-#include   <QFileInfo>
+#include <QMimeData>
+#include <QFileInfo>
 #include <QUrl>
 #include <QFileDialog>
 #include <QLineEdit>
@@ -17,12 +18,14 @@
 #include <QDirModel>
 #include <QGridLayout>
 #include <QCoreApplication>
-#include  <KFileDialog>
+#include <QFileDialog>
+#include <QStandardPaths>
 
 #include "con.h"
 #include "data_item.h"
 #include "sem_mediator.h"
 #include "image_view.h"
+#include "mem_command.h"
 
 image_view::image_view(QWidget *i_oParent, sem_mediator *i_oControl) : QWidget(i_oParent)
 {
@@ -33,11 +36,11 @@ image_view::image_view(QWidget *i_oParent, sem_mediator *i_oControl) : QWidget(i
 	setContextMenuPolicy(Qt::CustomContextMenu);
 	connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(context_menu(const QPoint&)));
 
-	m_oChangePictureAction = new QAction(trUtf8("Change picture"), this);
+	m_oChangePictureAction = new QAction(i18n("Change picture"), this);
         connect(m_oChangePictureAction, SIGNAL(triggered()), this, SLOT(change_pic()));
 	addAction(m_oChangePictureAction);
 
-	m_oClearPictureAction = new QAction(trUtf8("Clear picture"), this);
+	m_oClearPictureAction = new QAction(i18n("Clear picture"), this);
         connect(m_oClearPictureAction, SIGNAL(triggered()), this, SLOT(clear_pic()));
 	addAction(m_oClearPictureAction);
 
@@ -62,11 +65,11 @@ void image_view::paintEvent(QPaintEvent*)
 	{
 		if (m_iId)
 		{
-			p.drawText(r, Qt::AlignCenter, trUtf8("Click to set a picture"));
+			p.drawText(r, Qt::AlignCenter, i18n("Click to set a picture"));
 		}
 		else
 		{
-			p.drawText(r, Qt::AlignCenter, trUtf8("Select an item on the map"));
+			p.drawText(r, Qt::AlignCenter, i18n("Select an item on the map"));
 		}
 		return;
 	}
@@ -100,8 +103,8 @@ void image_view::notify_select(const QList<int>& unsel, const QList<int>& sel) {
 	bool one = (sel.size() == 1);
 	if (one) {
 		m_iId = sel.at(0);
-		data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
-		m_oPixmap = l_oData->getPix();
+		data_item& l_oData = m_oMediator->m_oItems[m_iId];
+		m_oPixmap = l_oData.getPix(m_oMediator);
 	} else {
 		m_oPixmap = QPixmap();
 		m_iId = NO_ITEM;
@@ -111,16 +114,15 @@ void image_view::notify_select(const QList<int>& unsel, const QList<int>& sel) {
 
 void image_view::clear_pic()
 {
-	data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+	data_item& l_oData = m_oMediator->m_oItems[m_iId];
 
 	mem_pic *mem = new mem_pic(m_oMediator);
-	mem->sel = l_oData;
-	mem->m_iOldId = l_oData->m_iPicId;
+	mem->m_iId = m_iId;
+	mem->m_iOldId = l_oData.m_iPicId;
 	mem->m_iNewId = NO_ITEM;
 	mem->apply();
 }
 
-#include "image_view.moc"
 
 bool image_view::event(QEvent *i_oEvent)
 {
@@ -129,8 +131,8 @@ bool image_view::event(QEvent *i_oEvent)
 		if (m_iId)
 		{
 			QHelpEvent *l_oEv = static_cast<QHelpEvent*>(i_oEvent);
-			data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
-			QToolTip::showText(l_oEv->globalPos(), l_oData->m_sPicLocation);
+			data_item& l_oData = m_oMediator->m_oItems[m_iId];
+			QToolTip::showText(l_oEv->globalPos(), l_oData.m_sPicLocation);
 		}
         }
 	return QWidget::event(i_oEvent);
@@ -161,27 +163,27 @@ void image_view::mouseReleaseEvent(QMouseEvent *i_o)
 
 void image_view::change_pic()
 {
-	KUrl l_o = KFileDialog::getOpenUrl(KUrl(notr("kfiledialog:///image")),
-                trUtf8("*.png *.jpg *.jpeg *.gif|Image Files (*.png *.jpg *.jpeg *.gif)"),
-                this, trUtf8("Choose a picture"));
+	QUrl l_o = QFileDialog::getOpenFileUrl(this, i18n("Choose a picture"), 
+                QUrl(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation)),
+                i18n("*.png *.jpg *.jpeg *.gif|Image Files (*.png *.jpg *.jpeg *.gif)"));
 	do_change_pic(l_o);
 }
 
-void image_view::do_change_pic(const KUrl& l_sText)
+void image_view::do_change_pic(const QUrl& l_sText)
 {
-	data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+	data_item& l_oData = m_oMediator->m_oItems[m_iId];
 	int id = m_oMediator->next_pic_seq();
 
 	bool l_bRet = m_oMediator->save_and_load_picture(l_sText, id);
 	if (!l_bRet)
 	{
-		emit sig_message(trUtf8("Could not load the picture"), 20000);
+		emit sig_message(i18n("Could not load the picture"), 20000);
 		return;
 	}
 
 	mem_pic *mem = new mem_pic(m_oMediator);
-	mem->sel = l_oData;
-	mem->m_iOldId = l_oData->m_iPicId;
+	mem->m_iId = m_iId;
+	mem->m_iOldId = l_oData.m_iPicId;
 	mem->m_iNewId = id;
 	mem->apply();
 }
@@ -238,28 +240,29 @@ void image_view::notify_pic(int id)
 {
 	if (m_iId == id)
 	{
-		data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
-		m_oPixmap = l_oData->getPix();
+		data_item& l_oData = m_oMediator->m_oItems[m_iId];
+		m_oPixmap = l_oData.getPix(m_oMediator);
 		repaint();
 	}
 }
 
 void image_view::notify_export_item(int id)
 {
-	data_item *l_oData = m_oMediator->m_oItems.value(id);
-	if (l_oData->m_iDataType != VIEW_IMG)
+	data_item& l_oData = m_oMediator->m_oItems[id];
+	if (l_oData.m_iDataType != VIEW_IMG)
 		return;
-	if (l_oData->m_iPicId != NO_ITEM)
+	if (l_oData.m_iPicId != NO_ITEM)
 	{
 		QDir l_oDir(m_oMediator->m_sTempDir);
 		QFileInfoList l_oLst = l_oDir.entryInfoList();
 		foreach (QFileInfo l_oInfo, l_oLst) {
 			QString l_sName = l_oInfo.fileName();
-			if (l_sName.startsWith(notr("img-%1").arg(QString::number(l_oData->m_iPicId))))
+			if (l_sName.startsWith(notr("img-%1").arg(QString::number(l_oData.m_iPicId))))
 			{
 				QFile f(l_oInfo.absoluteFilePath());
-				QString newName = l_oInfo.fileName().replace(QRegExp("img-\\d+"), QString("diag-%1").arg(QString::number(id)));
-				f.copy(newName); // TODO works for now
+				QString newName = l_oInfo.fileName().replace(QRegExp("img-\\d+"),
+					notr("%1/%2/diag-%3").arg(m_oMediator->m_sOutDir, m_oMediator->m_sOutProject, QString::number(id)));
+				f.copy(newName);
 				break;
 			}
 		}
