@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef LINEAR_VIEW_H
 #define LINEAR_VIEW_H
@@ -11,7 +11,7 @@ class QDragMoveEvent;
 class QDropEvent;
 class QMouseEvent;
 class QMimeData;
-
+class sem_mediator;
 class linear_view : public QTreeWidget
 {
 	Q_OBJECT
@@ -24,8 +24,10 @@ class linear_view : public QTreeWidget
 		bool filter_item(QTreeWidgetItem * i_oItem, const QString & i_oS);
 
 		void dropEvent(QDropEvent *);
+		void check_colors();
+		bool event(QEvent* i_oEvent);
 
-		bool m_bLockSelect;
+		int m_iLockSelect;
 
 	public slots:
 		void filter_slot(const QString & i_oS);
@@ -37,8 +39,9 @@ class linear_view : public QTreeWidget
 		void notify_link_items(int id1, int id2);
 		void notify_unlink_items(int id1, int id2);
 		void notify_select(const QList<int>& unsel, const QList<int>& sel);
-		void notify_sort(int id);
+		void notify_sort(int, bool);
 		void notify_edit(int id);
+		void notify_datatype(int);
 };
 
 #endif
