@@ -1,13 +1,11 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
-#include <khtml_part.h>
-#include <khtmlview.h>
-#include <KUrl>
+#include <QUrl>
 #include <QtDebug>
 #include <QLabel>
 #include <QTextBrowser>
 #include <QCoreApplication>
-#include <QWebView>
+#include <QWebEngineView>
 #include "data_item.h"
 #include "sem_mediator.h"
 #include "pre_view.h"
@@ -20,7 +18,7 @@ pre_view::pre_view(QWidget *i_oParent, sem_mediator *i_oControl) : QStackedWidge
 	m_oMediator = i_oControl;
 
 	m_oLabel = new QLabel(this);
-	m_oLabel->setText(trUtf8("<p align='center'>No preview available<br/>at this time</p>"));
+	m_oLabel->setText(i18n("<p align='center'>No preview available<br/>at this time</p>"));
 	addWidget(m_oLabel);
 
 	/*m_oBrowserObject = new KHTMLPart(this, this);
@@ -41,14 +39,14 @@ void pre_view::notify_preview()
 		}
 		else
 		{
-			m_oBrowser->load(QUrl(l_s));
+				m_oBrowser->load(QUrl("file://" + l_s));
 			m_oBrowser->show();
 		}
 		setCurrentWidget(m_oBrowser);
 	}
 	else if (l_s.endsWith(notr(".tex")))
 	{
-		//m_oBrowser->openUrl(KUrl(l_s));
+		//m_oBrowser->openUrl(QUrl(l_s));
 		//setCurrentWidget(m_oBrowser);
 	}
 	else
@@ -58,5 +56,3 @@ void pre_view::notify_preview()
 
 }
 
-#include "pre_view.moc"
-
