@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef PRE_VIEW_H
 #define PRE_VIEW_H
@@ -8,7 +8,8 @@
 
 class browser;
 class QLabel;
-class QWebView;
+class QWebEngineView;
+class sem_mediator;
 class pre_view : public QStackedWidget
 {
 	Q_OBJECT
