@@ -1,55 +1,61 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QtGui>
 #include <QFile>
+ # include <QDir>
 #include <QTextBrowser>
 #include <QProgressDialog>
-#include <KStatusBar>
-#include <KFileDialog>
+#include <KDE/KStatusBar>
+#include <QFileDialog>
 #include <KConfigGroup>
-#include <KMenuBar>
-#include <KApplication>
+#include <QMenuBar>
+#include <KDE/KApplication>
 #include <KStandardAction>
 #include <KRecentFilesAction>
 #include <KActionCollection>
-#include<KToolBar>
-#include <KAction>
-#include <KMenu>
+#include <KToolBar>
+#include <QMenu>
+#include <QIcon>
 #include <KMessageBox>
 #include <ktip.h>
+#include <windef.h>
 #include <QFrame>
+#include <QtWidgets>
+#include <QUuid>
+#include <QStandardPaths>
 
 #include "box_view.h"
-#include  "sembind.h"
+#include "sembind.h"
 #include "semantik.h"
-#include  "canvas_view.h"
-#include   "sem_mediator.h"
-#include    "image_view.h"
+#include "canvas_view.h"
+#include "sem_mediator.h"
+#include "image_view.h"
 #include "config_dialog.h"
-#include   "text_view.h"
-#include    "table_view.h"
-#include       "vars_view.h"
-#include      "pre_view.h"
-#include     "linear_container.h"
-#include    "template_entry.h"
-#include   "generator_dialog.h"
-#include  "data_view.h"
-#include    "doc_dialog.h"
-#include    "aux.h" 
+#include "text_view.h"
+#include "table_view.h"
+#include "vars_view.h"
+#include "pre_view.h"
+#include "linear_container.h"
+#include "template_entry.h"
+#include "generator_dialog.h"
+#include "data_view.h"
+#include "doc_dialog.h"
+#include "aux.h" 
 #include "linear_view.h"
+#include      "mem_command.h"
 
 void semantik_win::slot_generate()
 {
 	if (m_oMediator->choose_root() <= 0)
 	{
-		KMessageBox::sorry(this, trUtf8("The map is empty, Semantik\ncannot create documents from it"), trUtf8("Empty map"));
+		KMessageBox::sorry(this, i18n("The map is empty, Semantik\ncannot create documents from it"), i18n("Empty map"));
 		return;
 	}
 
 	QDir l_oDir(TEMPLATE_DIR);
 	if (!l_oDir.exists() || !l_oDir.isReadable())
 	{
-		slot_message(trUtf8("Template folder %1 is not readable").arg(TEMPLATE_DIR), 5000);
+		slot_message(i18n("Template folder %1 is not readable", TEMPLATE_DIR), 5000);
 		return;
 	}
 	QFileInfoList l_o = l_oDir.entryInfoList(QStringList()<<"*.py", QDir::Files, QDir::Name);
@@ -132,20 +138,25 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 {
 	setObjectName("semantik_win");
 
-	setWindowIcon(KIcon("semantik"));
+	setWindowIcon(QIcon("semantik"));
 
+	m_oWindef = new windef();
 	m_oMediator = new sem_mediator(this);
+	m_oMediator->m_oWindef = m_oWindef;
 	connect(m_oMediator, SIGNAL(sig_message(const QString&, int)), this, SLOT(slot_message(const QString&, int)));
-	connect(m_oMediator, SIGNAL(update_title()), this, SLOT(update_title()));
+	connect(m_oMediator, SIGNAL(sig_update_title()), this, SLOT(update_title()));
+
+	m_oColorMenu = new QMenu(i18n("Colors"), this);
 
 	QFrame *fr = new QFrame(this);
 	fr->setLineWidth(0);
 	fr->setFrameStyle(QFrame::NoFrame);
-	m_oCanvas = new canvas_view(fr, m_oMediator);
+	m_oCanvas = new canvas_view(fr, m_oMediator, m_oColorMenu);
 	setCentralWidget(fr);
 	QGridLayout *ll = new QGridLayout(fr);
 	ll->addWidget(m_oCanvas);
 	m_oCanvas->m_oSemantikWindow = this;
+	m_oCanvas->setupActions(actionCollection());
 
 	connect(m_oCanvas, SIGNAL(sig_message(const QString&, int)), this, SLOT(slot_message(const QString&, int)));
 
@@ -154,51 +165,46 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	KStandardAction::save(this, SLOT(slot_save()), actionCollection());
 	KStandardAction::saveAs(this, SLOT(slot_save_as()), actionCollection());
 	KStandardAction::open(this, SLOT(slot_open()), actionCollection());
-	KStandardAction::print(this, SLOT(slot_print()), actionCollection());
+	KStandardAction::print(m_oCanvas, SLOT(slot_print()), actionCollection());
 	KStandardAction::tipOfDay(this, SLOT(slot_tip_of_day()), actionCollection());
 	m_oUndoAct = KStandardAction::undo(m_oMediator, SLOT(slot_undo()), actionCollection());
 	m_oUndoAct->setEnabled(false);
 	m_oRedoAct = KStandardAction::redo(m_oMediator, SLOT(slot_redo()), actionCollection());
 	m_oRedoAct->setEnabled(false);
 
-	m_oRecentFilesAct = KStandardAction::openRecent(this, SLOT(slot_recent(const KUrl&)), actionCollection());
+	m_oRecentFilesAct = KStandardAction::openRecent(this, SLOT(slot_recent(const QUrl&)), actionCollection());
 
-	m_oReorgAct = new KAction(trUtf8("&Reorganize the map"), this);
+	m_oReorgAct = new QAction(i18n("&Reorganize the map"), this);
 	actionCollection()->addAction(notr("reorganize_map"), m_oReorgAct);
-	m_oReorgAct->setShortcut(trUtf8("Ctrl+R"));
+	actionCollection()->setDefaultShortcut(m_oReorgAct, i18n("Ctrl+R"));
 	connect(m_oReorgAct, SIGNAL(triggered(bool)), m_oCanvas, SLOT(reorganize()));
 
-	m_oExportSizeAct = new KAction(trUtf8("&Export the map..."), this);
+	m_oExportSizeAct = new QAction(i18n("&Export the map..."), this);
 	actionCollection()->addAction(notr("export_map_size"), m_oExportSizeAct);
-	m_oExportSizeAct->setShortcut(trUtf8("Ctrl+Shift+E"));
+	actionCollection()->setDefaultShortcut(m_oExportSizeAct, i18n("Ctrl+Shift+E"));
 	connect(m_oExportSizeAct, SIGNAL(triggered(bool)), m_oCanvas, SLOT(export_map_size()));
 
 	KStandardAction::preferences(this, SLOT(slot_properties()), actionCollection());
 
-	m_oGenerateAct = new KAction(trUtf8("&Generate..."), this);
+	m_oGenerateAct = new QAction(i18n("&Generate..."), this);
 	actionCollection()->addAction(notr("generate_doc"), m_oGenerateAct);
-	m_oGenerateAct->setIcon(KIcon(notr("run-build-file")));
-	m_oGenerateAct->setShortcut(trUtf8("Ctrl+G"));
+	m_oGenerateAct->setIcon(QIcon(notr("run-build-file")));
+	actionCollection()->setDefaultShortcut(m_oGenerateAct, i18n("Ctrl+G"));
 	connect(m_oGenerateAct, SIGNAL(triggered(bool)), SLOT(slot_generate()));
 
-	flag_scheme l_oScheme(this, notr("crsc-app-colors"), "");
+	m_oImportDocAct = new QAction(i18n("&Import a map..."), this);
+	actionCollection()->addAction(notr("import_doc"), m_oImportDocAct);
+	actionCollection()->setDefaultShortcut(m_oImportDocAct, i18n("Ctrl+I"));
+	connect(m_oImportDocAct, SIGNAL(triggered(bool)), SLOT(slot_import_doc()));
 
-	m_oColorGroup = new QActionGroup(this);
-	m_oCustomColorAct = new QAction(l_oScheme._icon(), trUtf8("CustomColor"), m_oColorGroup);
-	m_oColorGroup->setExclusive(true);
-	connect(m_oColorGroup, SIGNAL(triggered(QAction*)), m_oCanvas, SLOT(change_colors(QAction*)));
 
-	m_oFlagGroup = new QActionGroup(this);
-	m_oFlagGroup->setExclusive(false);
-	connect(m_oFlagGroup, SIGNAL(triggered(QAction*)), m_oCanvas, SLOT(change_flags(QAction*)));
-
-	//m_oCanvasFitZoom = new KAction(trUtf8("Fit zoom"), this);
+	//m_oCanvasFitZoom = new QAction(i18n("Fit zoom"), this);
 	//actionCollection()->addAction(notr("zoom_map"), m_oCanvasFitZoom);
-	//m_oCanvasFitZoom->setIcon(KIcon(notr("zoom-best-fit")));
+	//m_oCanvasFitZoom->setIcon(QIcon(notr("zoom-best-fit")));
 	//connect(m_oCanvasFitZoom, SIGNAL(triggered(bool)), m_oCanvas, SLOT(fit_zoom()));
-	m_oCanvasFitZoom = KStandardAction::fitToPage(m_oCanvas, SLOT(fit_zoom()), actionCollection());
-	m_oCanvasFitZoom->setIcon(KIcon(notr("zoom-best-fit")));
-	m_oCanvasFitZoom->setShortcut(trUtf8("Ctrl+H"));
+	m_oCanvasFitZoom = KStandardAction::fitToPage(this, SLOT(fit_zoom()), actionCollection());
+	m_oCanvasFitZoom->setIcon(QIcon(notr("zoom-best-fit")));
+	actionCollection()->setDefaultShortcut(m_oCanvasFitZoom, i18n("Ctrl+H"));
 
 	KStandardAction::zoomIn(m_oCanvas, SLOT(zoom_in()), actionCollection());
 	KStandardAction::zoomOut(m_oCanvas, SLOT(zoom_out()), actionCollection());
@@ -207,7 +213,7 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	//setStandardToolBarMenuEnabled(true);
 
 
-	QDockWidget *l_oDockData = new QDockWidget(trUtf8("Data"), this);
+	QDockWidget *l_oDockData = new QDockWidget(i18n("Data"), this);
 	l_oDockData->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea | Qt::BottomDockWidgetArea);
 	m_oDataView = new data_view(l_oDockData, m_oMediator);
 	l_oDockData->setWidget(m_oDataView);
@@ -225,12 +231,13 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	m_oDataView->addWidget(m_oTableView);
 
 	m_oDiagramView = new box_view(m_oDataView, m_oMediator);
+	m_oDiagramView->m_bShowFileMenu = true;
+	m_oDiagramView->m_oColorMenu = m_oColorMenu;
 	m_oDataView->addWidget(m_oDiagramView);
-	connect(m_oColorGroup, SIGNAL(triggered(QAction*)), m_oDiagramView, SLOT(change_colors(QAction*)));
 	connect(m_oDiagramView, SIGNAL(sig_message(const QString&, int)), this, SLOT(slot_message(const QString&, int)));
 
 
-	QDockWidget *l_oDockVars = new QDockWidget(trUtf8("Variables"), this);
+	QDockWidget *l_oDockVars = new QDockWidget(i18n("Variables"), this);
 	l_oDockVars->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea | Qt::BottomDockWidgetArea);
 	m_oVarsView = new vars_view(l_oDockVars, m_oMediator);
 	l_oDockVars->setWidget(m_oVarsView);
@@ -239,7 +246,7 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	actionCollection()->addAction(notr("show_dock_vars"), l_oDockVars->toggleViewAction());
 	m_oVarsView->init_completer();
 
-	QDockWidget *l_oDockPreview = new QDockWidget(trUtf8("Preview"), this);
+	QDockWidget *l_oDockPreview = new QDockWidget(i18n("Preview"), this);
 	l_oDockPreview->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea | Qt::BottomDockWidgetArea);
 	m_oPreView = new pre_view(l_oDockPreview, m_oMediator);
 	l_oDockPreview->setWidget(m_oPreView);
@@ -251,23 +258,55 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	tabifyDockWidget(l_oDockData, l_oDockVars);
 
 
-	QDockWidget *l_oDock = new QDockWidget(trUtf8("Linear view"), this);
+	QDockWidget *l_oDock = new QDockWidget(i18n("Linear view"), this);
 	m_oTree = new linear_container(l_oDock, m_oMediator);
 	l_oDock->setWidget(m_oTree);
 	addDockWidget(Qt::LeftDockWidgetArea, l_oDock);
 	actionCollection()->addAction(notr("show_dock_linear"), l_oDock->toggleViewAction());
 	l_oDock->setObjectName(notr("LinearDock"));
 
+	flag_scheme l_oScheme(notr("crsc-app-colors"), "");
+	m_oColorGroup = new QActionGroup(this);
+	for (int i = 0; i < 9; ++i)
+	{
+		QAction *l_oAct = new QAction(QIcon(), i18n("Color"), m_oColorGroup);
+		m_oColorGroup->addAction(l_oAct);
+		actionCollection()->addAction(QString("color_%1").arg(QString::number(i)), l_oAct);
+		if (i != 0)
+		{
+			m_oColorMenu->addAction(l_oAct);
+		}
+	}
 
-	setXMLFile(notr("semantikui.rc"));
-	setupGUI();
+	m_oCustomColorAct = new QAction(l_oScheme._icon(), i18n("Custom color"), m_oColorGroup);
+	m_oColorMenu->addAction(m_oCustomColorAct);
+	m_oColorGroup->setExclusive(true);
+	actionCollection()->addAction(notr("color_custom"), m_oCustomColorAct);
 
-	m_oMediator->m_oCurrentUrl = KUrl();
+	m_oFlagGroup = new QActionGroup(this);
+	m_oFlagGroup->setExclusive(false);
+	connect(m_oFlagGroup, SIGNAL(triggered(QAction*)), m_oCanvas, SLOT(change_flags(QAction*)));
+
+	for (int i = 0; i < 16; ++i)
+	{
+		QAction *l_oAct = new QAction(QIcon(notr("crsc-app-colors")), i18n("Flag"), m_oFlagGroup);
+		l_oAct->setCheckable(true);
+		m_oFlagGroup->addAction(l_oAct);
+		actionCollection()->addAction(QString("flag_%1").arg(QString::number(i)), l_oAct);
+	}
+
+	setupGUI(QSize(800, 800), Default, notr("semantikui.rc"));
+
+	connect(m_oMediator, SIGNAL(sync_colors()), this, SLOT(sync_colors()));
+	connect(m_oMediator, SIGNAL(sync_font()), m_oCanvas, SLOT(notify_font()));
+	connect(m_oColorGroup, SIGNAL(triggered(QAction*)), m_oDiagramView, SLOT(change_colors(QAction*)));
+	connect(m_oColorGroup, SIGNAL(triggered(QAction*)), m_oCanvas, SLOT(change_colors(QAction*)));
+
+	connect(m_oMediator, SIGNAL(sync_background_color()), m_oCanvas, SLOT(slot_background_color()));
+
+	m_oMediator->m_oCurrentUrl = QUrl();
 	update_title();
 
-	m_oColorsToolBar = toolBar(notr("colorsToolBar"));
-	m_oFlagsToolBar = toolBar(notr("flagsToolBar"));
-
 	linear_view* ln = m_oTree->m_oView;
 	connect(m_oMediator, SIGNAL(sig_preview()), m_oPreView, SLOT(notify_preview()));
 	connect(m_oMediator, SIGNAL(sig_add_item(int)), m_oCanvas, SLOT(notify_add_item(int)));
@@ -280,6 +319,8 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	connect(m_oMediator, SIGNAL(sig_link_items(int, int)), ln, SLOT(notify_link_items(int, int)));
 	connect(m_oMediator, SIGNAL(sig_unlink_items(int, int)), m_oCanvas, SLOT(notify_unlink_items(int, int)));
 	connect(m_oMediator, SIGNAL(sig_unlink_items(int, int)), ln, SLOT(notify_unlink_items(int, int)));
+	connect(m_oMediator, SIGNAL(sig_ref_items(int, int)), m_oCanvas, SLOT(notify_ref_items(int, int)));
+	connect(m_oMediator, SIGNAL(sig_unref_items(int, int)), m_oCanvas, SLOT(notify_unref_items(int, int)));
 	connect(m_oMediator, SIGNAL(sig_repaint(int)), m_oCanvas, SLOT(notify_repaint(int)));
 	connect(m_oMediator, SIGNAL(sig_repaint(int)), ln, SLOT(notify_repaint(int)));
 
@@ -301,23 +342,24 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	connect(m_oMediator, SIGNAL(sig_select(const QList<int>&, const QList<int>&)), m_oDiagramView, SLOT(notify_select(const QList<int>&, const QList<int>&)));
 	connect(m_oMediator, SIGNAL(sig_select(const QList<int>&, const QList<int>&)), ln, SLOT(notify_select(const QList<int>&, const QList<int>&)));
 
-	connect(m_oMediator, SIGNAL(sig_sort(int)), m_oCanvas, SLOT(notify_sort(int)));
-	connect(m_oMediator, SIGNAL(sig_sort(int)), ln, SLOT(notify_sort(int)));
+	connect(m_oMediator, SIGNAL(sig_sort(int, bool)), m_oCanvas, SLOT(notify_sort(int, bool)));
+	connect(m_oMediator, SIGNAL(sig_sort(int, bool)), ln, SLOT(notify_sort(int, bool)));
 
 
 	connect(m_oMediator, SIGNAL(sig_datatype(int)), m_oDataView, SLOT(notify_datatype(int)));
+	connect(m_oMediator, SIGNAL(sig_datatype(int)), m_oCanvas, SLOT(notify_datatype(int)));
+	connect(m_oMediator, SIGNAL(sig_datatype(int)), ln, SLOT(notify_datatype(int)));
 
 	connect(m_oMediator, SIGNAL(sig_pic(int)), m_oCanvas, SLOT(notify_pic(int)));
 	connect(m_oMediator, SIGNAL(sig_pic(int)), m_oImageView, SLOT(notify_pic(int)));
 
 	connect(m_oMediator, SIGNAL(sig_move(const QList<int>&, const QList<QPointF>&)), m_oCanvas, SLOT(notify_move(const QList<int>&, const QList<QPointF>&)));
 
-	connect(m_oMediator, SIGNAL(sync_flags()), m_oCanvas, SLOT(sync_flags()));
-	connect(m_oMediator, SIGNAL(sync_colors()), m_oCanvas, SLOT(sync_colors()));
-
+	connect(m_oMediator, SIGNAL(sync_flags()), this, SLOT(sync_flags()));
 	connect(m_oImageView, SIGNAL(sig_message(const QString&, int)), this, SLOT(slot_message(const QString&, int)));
 
 	connect(m_oMediator, SIGNAL(sig_open_map()), m_oCanvas, SLOT(notify_open_map()));
+	connect(m_oMediator, SIGNAL(sig_open_map()), m_oVarsView, SLOT(notify_open_map()));
 	connect(m_oMediator, SIGNAL(sig_change_data(int)), m_oCanvas, SLOT(notify_change_data(int)));
 
 	connect(m_oMediator, SIGNAL(sig_export_doc()), m_oCanvas, SLOT(notify_export_doc()));
@@ -333,8 +375,11 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	connect(m_oMediator, SIGNAL(sig_box_props(int, const QList<diagram_item*>&)), m_oDiagramView, SLOT(notify_box_props(int, const QList<diagram_item*>&)));
 	connect(m_oMediator, SIGNAL(sig_pos_box(int, const QList<data_box*>&)), m_oDiagramView, SLOT(notify_pos_box(int, const QList<data_box*>&)));
 	connect(m_oMediator, SIGNAL(sig_size_box(int, const QList<data_box*>&)), m_oDiagramView, SLOT(notify_size_box(int, const QList<data_box*>&)));
+	connect(m_oMediator, SIGNAL(sig_text_align(int, const QList<data_box>&)), m_oDiagramView, SLOT(notify_text_align(int, const QList<data_box>&)));
+	connect(m_oMediator, SIGNAL(sig_sequence_box(int, int)), m_oDiagramView, SLOT(notify_sequence_box(int, int)));
 	connect(m_oMediator, SIGNAL(sig_focus(void *)), m_oDiagramView, SLOT(notify_focus(void *)));
 	connect(m_oMediator, SIGNAL(sig_focus(void *)), m_oCanvas, SLOT(notify_focus(void *)));
+	connect(m_oMediator, SIGNAL(sig_change_properties(void *)), m_oDiagramView, SLOT(notify_change_properties(void *)));
 
 	m_oTree->m_oView->addAction(m_oCanvas->m_oDeleteAction); // FIXME
 
@@ -344,21 +389,55 @@ semantik_win::semantik_win(QWidget *i_oParent) : KXmlGuiWindow(i_oParent)
 	m_oMediator->init_flags();
 
 	read_config();
-	statusBar()->showMessage(trUtf8("Welcome to Semantik"), 2000);
+	m_oMediator->notify_background_color();
+	statusBar()->showMessage(i18n("Welcome to Semantik"), 2000);
 	setAutoSaveSettings();
 
 	connect(m_oMediator, SIGNAL(enable_undo(bool, bool)), this, SLOT(slot_enable_undo(bool, bool)));
 	KTipDialog::showTip(this, notr("semantik/tips"));
 }
 
+void semantik_win::fit_zoom()
+{
+	if (m_oCanvas->hasFocus())
+	{
+		m_oCanvas->fit_zoom();
+	}
+	else if (m_oDiagramView->hasFocus())
+	{
+		m_oDiagramView->fit_zoom();
+	}
+}
+
 void semantik_win::read_config()
 {
-	KConfigGroup l_oConfig(KGlobal::config(), notr("General Options"));
-	m_oRecentFilesAct->loadEntries(KGlobal::config()->group(notr("Recent Files")));
+	KConfig l_oCfg("semantik");
+	KConfigGroup l_oConfig(&l_oCfg, notr("General Options"));
+
+	KConfigGroup l_oSaveConfig(&l_oCfg, notr("Recent Files"));
+	m_oRecentFilesAct->loadEntries(l_oSaveConfig);
+
 	move(l_oConfig.readEntry(notr("winpos"), QPoint(0, 0)));
-	m_oCanvas->setBackgroundBrush(QColor(l_oConfig.readEntry(notr("bgcolor"), notr("#FFFDE8"))));
-	m_oMediator->m_sOutDir = l_oConfig.readEntry(notr("outdir"), notr("/tmp/"));
+	m_oMediator->m_iForceTime = l_oConfig.readEntry(notr("force_time"), "500").toInt();
+	m_oMediator->m_dForceLen = l_oConfig.readEntry(notr("force_len"), "2").toDouble();
+	m_oMediator->m_oColor = QColor(l_oConfig.readEntry(notr("bgcolor"), notr("#FFFDE8")));
+	m_oMediator->m_oArrowColor = QColor(l_oConfig.readEntry(notr("arrowcolor"), notr("#000000")));
+	m_oMediator->m_oAltArrowColor = QColor(l_oConfig.readEntry(notr("altarrowcolor"), notr("#e0e0e0")));
+	m_oMediator->m_sOutDir = l_oConfig.readEntry(notr("outdir"), QDir::homePath());
+	m_oMediator->m_sGlobalHints = l_oConfig.readEntry(notr("global_hints"));
 	bind_node::set_var(notr("outdir"), m_oMediator->m_sOutDir);
+	m_oWindef->m_bUseTouchpad = l_oConfig.readEntry(notr("touchpad"), false);
+
+	QString l_oGuidString = l_oConfig.readEntry(notr("guid"));
+	if (!l_oGuidString.isEmpty())
+	{
+		m_oQUuid = QUuid(l_oGuidString);
+	}
+	else
+	{
+		m_oQUuid = QUuid::createUuid();
+		write_config();
+	}
 
 	//QString lang_code(config.readEntry("currentLanguageCode", QVariant(QString())).toString());
 	//if (lang_code.isEmpty()) lang_code = "en_US";  // null-string are saved as empty-strings
@@ -367,12 +446,16 @@ void semantik_win::read_config()
 
 void semantik_win::write_config()
 {
-	KConfigGroup l_oConfig(KGlobal::config(), notr("General Options"));
-	m_oRecentFilesAct->saveEntries(KGlobal::config()->group(notr("Recent Files")));
+	KConfig l_oCfg("semantik");
+	KConfigGroup l_oConfig(&l_oCfg, notr("General Options"));
 	l_oConfig.writeEntry(notr("winpos"), pos());
 	l_oConfig.writeEntry(notr("outdir"), bind_node::get_var(notr("outdir")));
-	//config.writeEntry("currentLanguageCode", currentLanguageCode);
+	l_oConfig.writeEntry(notr("guid"), m_oQUuid.toString());
 	l_oConfig.sync();
+
+	KConfigGroup l_oSaveConfig(&l_oCfg, notr("Recent Files"));
+	m_oRecentFilesAct->saveEntries(l_oSaveConfig);
+	l_oSaveConfig.sync();
 }
 
 semantik_win::~semantik_win()
@@ -380,20 +463,7 @@ semantik_win::~semantik_win()
 
 }
 
-void semantik_win::slot_print()
-{
-        QPrinter *l_oP = new QPrinter;
-	//l_oP->setResolution(QPrinter::HighResolution);
-        QPrintDialog l_oD(l_oP, m_oCanvas);
-        if (l_oD.exec() == QDialog::Accepted)
-        {
-                QPainter l_oPa(l_oP);
-                m_oCanvas->render(&l_oPa);
-        }
-        statusBar()->showMessage(trUtf8("Ready"), 2000);
-}
-
-int semantik_win::print_to_file(const QString & url, QPair<int, int> p)
+int semantik_win::print_to_file(const QUrl & url, QPair<int, int> p)
 {
 	return m_oCanvas->batch_print_map(url, p);
 }
@@ -401,42 +471,41 @@ int semantik_win::print_to_file(const QString & url, QPair<int, int> p)
 bool semantik_win::slot_save_as()
 {
 	choose:
-	KUrl l_o = KFileDialog::getSaveUrl(KUrl(notr("kfiledialog:///document")),
-		trUtf8("*.sem|Semantik file (*.sem)"), this,
-		trUtf8("Choose a file name"));
+	QUrl l_o = QFileDialog::getSaveFileUrl(this, i18n("Choose a file name"), 
+                QUrl(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)),
+		i18n("*.sem|Semantik file (*.sem)"));
 
 	if (l_o.path().isEmpty()) return false;
 	if (!l_o.path().endsWith(notr(".sem")))
 	{
-		l_o = KUrl(l_o.path()+notr(".sem"));
-	}
-
-	if (m_oMediator->m_sLastSaved != l_o.path())
-	{
-		if (l_o.isLocalFile() && QFile::exists(l_o.path()))
-		{
-			int mu = KMessageBox::questionYesNo(NULL, //this,
-			trUtf8("The file \"%1\" already exists.\nOverwrite it?").arg(l_o.path()),
-			trUtf8("Overwrite existing file"),
-			KStandardGuiItem::yes(),
-			KStandardGuiItem::no(),
-			notr("OverwriteExistingFile"));
-			if (!mu)
-				goto choose;
-		}
+		l_o = QUrl(l_o.path()+notr(".sem"));
 	}
 
 	if (m_oMediator->save_file(l_o.path()))
 	{
-		statusBar()->showMessage(trUtf8("Saved '%1'").arg(l_o.path()), 2000);
+		statusBar()->showMessage(i18n("Saved '%1'", l_o.path()), 2000);
 		m_oMediator->m_oCurrentUrl = l_o;
 		update_title();
 		return true;
 	}
 	else
 	{
-		m_oMediator->m_oCurrentUrl = KUrl();
+		m_oMediator->m_oCurrentUrl = QUrl();
 		update_title();
+
+		int mu = KMessageBox::questionYesNo(NULL, //this,
+		i18n("The file \"%1\" could not be saved because an error happened.\nTry again?", l_o.path()),
+		i18n("Try again?"),
+		KStandardGuiItem::yes(),
+		KStandardGuiItem::no(),
+		notr("ContinueSaveAs"));
+		if (mu == KMessageBox::Yes) {
+			goto choose;
+		}
+		else
+		{
+			return false;
+		}
 	}
 
 	return false;
@@ -450,9 +519,25 @@ bool semantik_win::slot_save()
 	}
 	if (m_oMediator->save_file(m_oMediator->m_sLastSaved))
 	{
-		statusBar()->showMessage(trUtf8("Saved '%1'").arg(m_oMediator->m_sLastSaved), 2000);
+		statusBar()->showMessage(i18n("Saved '%1'", m_oMediator->m_sLastSaved), 2000);
 		return true;
 	}
+	else
+	{
+		int mu = KMessageBox::questionYesNo(NULL, //this,
+		i18n("The file \"%1\" could not be saved because an error happened.\nTry again?", m_oMediator->m_sLastSaved),
+		i18n("Try again?"),
+		KStandardGuiItem::yes(),
+		KStandardGuiItem::no(),
+		notr("ContinueSaveAs"));
+		if (mu == KMessageBox::Yes) {
+			return slot_save_as();
+		}
+		else
+		{
+			return false;
+		}
+	}
 	return false;
 }
 
@@ -463,29 +548,25 @@ void semantik_win::slot_open()
 		if (!proceed_save()) return;
 	}
 
-	KUrl l_o = KFileDialog::getOpenUrl(KUrl(notr("kfiledialog:///document")),
-		trUtf8("*.sem *.kdi *.mm *.vym|All Supported Files (*.sem *.kdi *.mm *.vym)"),
-		this, trUtf8("Choose a file name"));
-	if (l_o.isValid() && m_oMediator->open_file(l_o.path()))
-	{
-		m_oMediator->m_oCurrentUrl = l_o;
-	}
-	update_title();
+	QUrl l_o = QFileDialog::getOpenFileUrl(this, i18n("Choose a file name"),
+                QUrl(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)),
+		i18n("*.sem *.kdi *.mm *.vym|All Supported Files (*.sem *.kdi *.mm *.vym)"));
+	if (l_o.isValid() && m_oMediator->open_file(l_o.path()));
 }
 
 void semantik_win::update_title()
 {
 	QString mod;
-	if (m_oMediator->m_bDirty) mod = trUtf8(" [Modified] ");
+	if (m_oMediator->m_bDirty) mod = i18n(" [Modified] ");
 
 	QString txt;
 	if (m_oMediator->m_oCurrentUrl.path().isEmpty())
 	{
-		txt = trUtf8("Semantik %1").arg(mod);
+		txt = i18n("Semantik %1", mod);
 	}
 	else
 	{
-		txt = trUtf8("%1 %2 - Semantik").arg(m_oMediator->m_oCurrentUrl.path(), mod);
+		txt = i18n("%1 %2 - Semantik", m_oMediator->m_oCurrentUrl.path(), mod);
 		m_oRecentFilesAct->addUrl(m_oMediator->m_oCurrentUrl); // TODO
 	}
 	setWindowTitle(txt);
@@ -496,47 +577,108 @@ void semantik_win::slot_properties()
 {
 	config_dialog l_oGen(this);
 
-	KConfigGroup l_oSettings(KGlobal::config(), notr("General Options"));
+	KConfig l_oCfg("semantik");
+	KConfigGroup l_oSettings(&l_oCfg, notr("General Options"));
 	l_oGen.m_oConnType->setCurrentIndex(l_oSettings.readEntry(notr("conn"), 0));
 	l_oGen.m_oReorgType->setCurrentIndex(l_oSettings.readEntry(notr("reorg"), 0));
 	l_oGen.m_oAutoSave->setValue(l_oSettings.readEntry(notr("auto"), 5));
+	l_oGen.m_oAutoReorg->setCurrentIndex(l_oSettings.readEntry(notr("autoReorg"), 1));
+	l_oGen.m_oUseTouchpad->setChecked(l_oSettings.readEntry(notr("touchpad"), false));
+	l_oGen.m_oPreviewPics->setChecked(m_oMediator->m_bShowPics);
 
-	QString l_o = l_oSettings.readEntry(notr("bgcolor"), notr("#FFFDE8"));
-	l_oGen.m_oColorWidget->setText(l_o);
-	QPalette l_oPalette = l_oGen.m_oColorWidget->palette();
-	l_oGen.m_oColor = QVariant(l_o).value<QColor>();
-	l_oPalette.setBrush(QPalette::Active, QPalette::Button, l_oGen.m_oColor);
-	l_oGen.m_oColorWidget->setPalette(l_oPalette);
+	l_oGen.m_oForceTime->setValue(m_oMediator->m_iForceTime);
+	l_oGen.m_oForceLen->setValue(m_oMediator->m_dForceLen);
+
+	QString l_sHint1 = i18n("Uncomment to set defaults to all documents");
+	QString l_sHint2 = i18n("Commands can only be defined here");
+	l_oGen.m_oTextEdit->setText(l_oSettings.readEntry(notr("global_hints"), notr("# %1\n# %2\n#\n# doc_company=XYZ\n# doc_author=Myself\n# command_pdflatex=cd %s/../ && ./run.sh\n# command_beamer=cd %s/../ && ./run.sh\n# command_html=firefox %s\n# command_s5=firefox %s\n# command_odt=oowriter %s\n# command_odp=ooimpress %s\n").arg(l_sHint1, l_sHint2)));
+
+	l_oGen.m_oColorWidget->setText(m_oMediator->m_oColor.name());
+	l_oGen.m_oArrowWidget->setText(m_oMediator->m_oArrowColor.name());
+	l_oGen.m_oAltArrowWidget->setText(m_oMediator->m_oAltArrowColor.name());
+
+	{
+		QPalette l_oPalette = l_oGen.m_oColorWidget->palette();
+		l_oGen.m_oColor = m_oMediator->m_oColor;
+		l_oPalette.setBrush(QPalette::Active, QPalette::Button, l_oGen.m_oColor);
+		l_oGen.m_oColorWidget->setPalette(l_oPalette);
+	}
+	{
+		QPalette l_oPalette = l_oGen.m_oArrowWidget->palette();
+		l_oGen.m_oArrowColor = m_oMediator->m_oArrowColor;
+		l_oPalette.setBrush(QPalette::Active, QPalette::Button, l_oGen.m_oArrowColor);
+		l_oGen.m_oArrowWidget->setPalette(l_oPalette);
+	}
+	{
+		QPalette l_oPalette = l_oGen.m_oAltArrowWidget->palette();
+		l_oGen.m_oAltArrowColor = m_oMediator->m_oAltArrowColor;
+		l_oPalette.setBrush(QPalette::Active, QPalette::Button, l_oGen.m_oAltArrowColor);
+		l_oGen.m_oAltArrowWidget->setPalette(l_oPalette);
+	}
 
 	if (l_oGen.exec() == QDialog::Accepted)
 	{
 		//m_oMediator->m_iConnType = l_oGen.m_oConnType->currentIndex();
 		//m_oMediator->m_iReorgType = l_oGen.m_oReorgType->currentIndex();
+		l_oSettings.writeEntry(notr("force_time"), m_oMediator->m_iForceTime = l_oGen.m_oForceTime->value());
+      	 	l_oSettings.writeEntry(notr("force_len"), m_oMediator->m_dForceLen = l_oGen.m_oForceLen->value());
 		l_oSettings.writeEntry(notr("conn"), m_oMediator->m_iConnType = l_oGen.m_oConnType->currentIndex());
-		l_oSettings.writeEntry(notr("reorg"), m_oMediator->m_iReorgType = l_oGen.m_oReorgType->currentIndex());
+		l_oSettings.writeEntry(notr("reorg"), m_oMediator->m_oWindef->m_iReorgType = l_oGen.m_oReorgType->currentIndex());
 		l_oSettings.writeEntry(notr("auto"), m_oMediator->m_iTimerValue = l_oGen.m_oAutoSave->value());
 		l_oSettings.writeEntry(notr("bgcolor"), l_oGen.m_oColor.name());
-		m_oMediator->init_timer();
+		l_oSettings.writeEntry(notr("arrowcolor"), l_oGen.m_oArrowColor.name());
+		l_oSettings.writeEntry(notr("altarrowcolor"), l_oGen.m_oAltArrowColor.name());
+		l_oSettings.writeEntry(notr("autoReorg"), m_oMediator->m_iAutoReorg = l_oGen.m_oAutoReorg->currentIndex());
+		l_oSettings.writeEntry(notr("touchpad"), m_oMediator->m_oWindef->m_bUseTouchpad = l_oGen.m_oUseTouchpad->isChecked());
+		QString l_sText = m_oMediator->m_sGlobalHints = l_oGen.m_oTextEdit->toPlainText();
+		if (l_sText.isEmpty())
+		{
+			l_oSettings.deleteEntry(notr("global_hints"));
+		}
+		else
+		{
+			l_oSettings.writeEntry(notr("global_hints"), l_sText);
+		}
 
-		m_oCanvas->setBackgroundBrush(l_oGen.m_oColor);
+		m_oMediator->set_show_pics(l_oGen.m_oPreviewPics->isChecked());
+
+		if (l_oGen.m_oColor != m_oMediator->m_oColor || m_oMediator->m_oArrowColor != l_oGen.m_oArrowColor || l_oGen.m_oAltArrowColor != m_oMediator->m_oAltArrowColor)
+		{
+			mem_all_color *l_oMem = new mem_all_color(m_oMediator);
+			l_oMem->m_oColor = l_oGen.m_oColor;
+			l_oMem->m_oArrowColor = l_oGen.m_oArrowColor;
+			l_oMem->m_oAltArrowColor = l_oGen.m_oAltArrowColor;
+
+			l_oMem->m_oOldColor = m_oMediator->m_oColor;
+			l_oMem->m_oOldArrowColor = m_oMediator->m_oArrowColor;
+			l_oMem->m_oOldAltArrowColor = m_oMediator->m_oAltArrowColor;
+			l_oMem->apply();
+		}
+		m_oMediator->init_timer();
+		l_oCfg.sync();
 	}
 }
 
 bool semantik_win::queryClose()
 {
 	write_config();
-	if (!m_oMediator->m_bDirty) return true;
-	return proceed_save();
+	if (!m_oMediator->m_bDirty)
+	{
+		return true;
+	}
+	bool l_bRet = proceed_save();
+	write_config();
+	return l_bRet;
 }
 
 bool semantik_win::proceed_save()
 {
 	QString l_oTitle = m_oMediator->m_sLastSaved;
-	if (l_oTitle.isEmpty()) l_oTitle = trUtf8("Untitled");
+	if (l_oTitle.isEmpty()) l_oTitle = i18n("Untitled");
 
 	int l_o = KMessageBox::warningYesNoCancel(NULL, //this,
-	trUtf8("The document \"%1\" has been modified.\nDo you want to save your changes or discard them?").arg(l_oTitle),
-	trUtf8("Close Document"),
+	i18n("The document \"%1\" has been modified.\nDo you want to save your changes or discard them?", l_oTitle),
+	i18n("Close Document"),
 	KStandardGuiItem::save(), KStandardGuiItem::discard());
 
 	switch (l_o)
@@ -551,16 +693,14 @@ bool semantik_win::proceed_save()
 	return false;
 }
 
-void semantik_win::slot_recent(const KUrl& i_oUrl)
+void semantik_win::slot_recent(const QUrl& i_oBadUrl)
 {
+	// deep copy or it will crash
+	QUrl i_oUrl = i_oBadUrl;
 	if (i_oUrl.path().isEmpty()) return;
-	if (m_oMediator->m_bDirty)
-	{
-		if (!proceed_save()) return;
-	}
-
 	if (m_oMediator->open_file(i_oUrl.path()))
 	{
+		m_oMediator->init_timer();
 		m_oMediator->m_oCurrentUrl = i_oUrl;
 	}
 	update_title();
@@ -581,5 +721,77 @@ void semantik_win::slot_enable_undo(bool undo, bool redo) {
 	m_oRedoAct->setEnabled(redo);
 }
 
-#include "semantik.moc"
+void process_icon(QIcon* i_oIcon, const QColor& i_oColor, int i_iSize)
+{
+	QPixmap l_oPix(i_iSize, i_iSize);
+	QPainter l_oP(&l_oPix);
+	l_oPix.fill(i_oColor);
+	l_oP.drawRect(0, 0, i_iSize -1, i_iSize -1);
+	i_oIcon->addPixmap(l_oPix);
+}
+
+void semantik_win::sync_colors()
+{
+	for (int i=0; i<m_oMediator->m_oColorSchemes.size(); ++i)
+	{
+		color_scheme l_oScheme = m_oMediator->m_oColorSchemes[i];
+		QAction *l_oAction = m_oColorGroup->actions().at(i);
+
+		QIcon l_oIcon;
+		process_icon(&l_oIcon, l_oScheme.m_oInnerColor, 22);
+		process_icon(&l_oIcon, l_oScheme.m_oInnerColor, 32);
+		process_icon(&l_oIcon, l_oScheme.m_oInnerColor, 64);
+		process_icon(&l_oIcon, l_oScheme.m_oInnerColor, 128);
+		l_oAction->setText(l_oScheme.m_sName);
+		l_oAction->setIcon(l_oIcon);
+	}
+}
+
+void semantik_win::sync_flags()
+{
+	for (int i=0; i<m_oMediator->m_oFlagSchemes.size(); ++i)
+	{
+		flag_scheme &l_oScheme = m_oMediator->m_oFlagSchemes[i];
+		QAction *l_oAction = m_oFlagGroup->actions().at(i);
+		l_oAction->setText(l_oScheme.m_sName);
+		l_oAction->setIcon(l_oScheme._icon());
+		l_oAction->setToolTip(i18n("Flag"));
+	}
+}
+
+void semantik_win::slot_import_doc()
+{
+	QUrl l_o = QFileDialog::getOpenFileUrl(this, i18n("Choose a file name"),
+		QUrl(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)),
+		i18n("*.sem *.kdi *.mm *.vym|All Supported Files (*.sem *.kdi *.mm *.vym)"));
+	if (l_o.isValid())
+	{
+		windef l_oWindef;
+		sem_mediator l_oMediator(this);
+		l_oMediator.m_oWindef = &l_oWindef;
+		if (l_oMediator.open_file(l_o.path()))
+		{
+			if (l_oMediator.m_oItems.size() == 0)
+			{
+				slot_message(i18n("Document '%1' is empty", l_o.path()), 10000);
+				return;
+			}
+
+			bool l_bOk = m_oMediator->copy_data(l_oMediator);
+			if (!l_bOk)
+			{
+				slot_message(i18n("Could not load pictures from '%1'", l_o.path()), 10000);
+				return;
+			}
+
+			mem_import_map *l_oMem = new mem_import_map(m_oMediator);
+			l_oMem->init_data(m_oMediator, &l_oMediator);
+			l_oMem->apply();
+		}
+		else
+		{
+			slot_message(i18n("Could not open '%1'", l_o.path()), 10000);
+		}
+	}
+}
 
