@@ -1,16 +1,16 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QSpinBox>
 #include <QtCore/QVariant>
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QButtonGroup>
-#include <QtGui/QDialog>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QGridLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QSpacerItem>
+#include <QAction>
+#include <QApplication>
+#include <QButtonGroup>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QGridLayout>
+#include <QLabel>
+#include <QLineEdit>
+#include <QSpacerItem>
 #include <QTreeWidget>
 #include <QTextEdit>
 #include <QHeaderView>
@@ -29,11 +29,11 @@ table_dialog::table_dialog(QWidget *i_oParent):
 	QLabel *l_sLabel;
 
 	l_sLabel = new QLabel(this);
-	l_sLabel->setText(trUtf8("Rows"));
+	l_sLabel->setText(i18n("Rows"));
 	l_oGridLayout->addWidget(l_sLabel, 0, 0, 1, 1);
 
 	l_sLabel = new QLabel(this);
-	l_sLabel->setText(trUtf8("Columns"));
+	l_sLabel->setText(i18n("Columns"));
 	l_oGridLayout->addWidget(l_sLabel, 1, 0, 1, 1);
 
 
@@ -62,4 +62,3 @@ table_dialog::table_dialog(QWidget *i_oParent):
 	resize(size);
 }
 
-#include "table_dialog.moc"
