@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QtDebug>
 #include <QAction>
@@ -6,14 +6,18 @@
 #include <QMouseEvent>
 #include <QSpinBox>
 #include<QCoreApplication>
+#include<QEvent>
+#include <QPlainTextEdit>
 
 #include "con.h"
 #include "table_dialog.h"
 #include "data_item.h"
 #include "sem_mediator.h"
 #include "table_view.h"
+#include "mem_command.h"
 
-numbered_action::numbered_action(QString x, QWidget *y) : QAction(x, y) {
+numbered_action::numbered_action(QString x, QWidget *y) : QAction(x, y)
+{
 
 }
 
@@ -22,29 +26,29 @@ table_view::table_view(QWidget *i_oParent, sem_mediator *i_oControl) : QTableWid
 	m_oMediator = i_oControl;
 	m_bFreeze = false;
 
-	m_oAddRowAct = new numbered_action(trUtf8("Add Row"), this);
-	m_oAddRowAct->setStatusTip(trUtf8("Add a row"));
+	m_oAddRowAct = new numbered_action(i18n("Add Row"), this);
+	m_oAddRowAct->setStatusTip(i18n("Add a row"));
         connect(m_oAddRowAct, SIGNAL(triggered()), this, SLOT(add_row()));
 	insertAction(0, m_oAddRowAct);
 
-	m_oAddColAct = new numbered_action(trUtf8("Add Column"), this);
-	m_oAddColAct->setStatusTip(trUtf8("Add a column"));
+	m_oAddColAct = new numbered_action(i18n("Add Column"), this);
+	m_oAddColAct->setStatusTip(i18n("Add a column"));
         connect(m_oAddColAct, SIGNAL(triggered()), this, SLOT(add_column()));
 	insertAction(0, m_oAddColAct);
 
 
-	m_oRmRowAct = new numbered_action(trUtf8("Remove Row"), this);
-	m_oRmRowAct->setStatusTip(trUtf8("Remove a row"));
+	m_oRmRowAct = new numbered_action(i18n("Remove Row"), this);
+	m_oRmRowAct->setStatusTip(i18n("Remove a row"));
         connect(m_oRmRowAct, SIGNAL(triggered()), this, SLOT(rm_row()));
 	insertAction(0, m_oRmRowAct);
 
-	m_oRmColAct = new numbered_action(trUtf8("Remove Column"), this);
-	m_oRmColAct->setStatusTip(trUtf8("Remove a column"));
+	m_oRmColAct = new numbered_action(i18n("Remove Column"), this);
+	m_oRmColAct->setStatusTip(i18n("Remove a column"));
         connect(m_oRmColAct, SIGNAL(triggered()), this, SLOT(rm_column()));
 	insertAction(0, m_oRmColAct);
 
-	QAction *m_oClearAct = new QAction(trUtf8("Redimension"), this);
-	m_oClearAct->setStatusTip(trUtf8("Change table dimensions"));
+	QAction *m_oClearAct = new QAction(i18n("Redimension"), this);
+	m_oClearAct->setStatusTip(i18n("Change table dimensions"));
         connect(m_oClearAct, SIGNAL(triggered()), this, SLOT(resize_table()));
 	insertAction(0, m_oClearAct);
 
@@ -54,6 +58,8 @@ table_view::table_view(QWidget *i_oParent, sem_mediator *i_oControl) : QTableWid
         l_oPalette.setBrush(QPalette::Disabled, QPalette::Base, QColor(230, 230, 230));
 	setPalette(l_oPalette);
 
+	table_view_filter* l_oFilter = new table_view_filter(this);
+	setItemDelegate(l_oFilter);
 	connect(this, SIGNAL(cellChanged(int, int)), this, SLOT(cell_changed(int, int)));
 }
 
@@ -76,16 +82,17 @@ void table_view::mousePressEvent(QMouseEvent *i_oEv)
 		m_oRmColAct->row = m_oRmRowAct->row = m_oAddRowAct->row = m_oAddColAct->row = i;
 		m_oRmColAct->col = m_oRmRowAct->col = m_oAddRowAct->col = m_oAddColAct->col = j;
 
-		m_oAddRowAct->setText(QString("%1 (%2)").arg(trUtf8("Add Row"), QString::number(i)));
-		m_oAddColAct->setText(QString("%1 (%2)").arg(trUtf8("Add Column"), QString::number(j)));
-		m_oRmRowAct->setText(QString("%1 (%2)").arg(trUtf8("Remove Row"), QString::number(i)));
-		m_oRmColAct->setText(QString("%1 (%2)").arg(trUtf8("Remove Column"), QString::number(j)));
+		m_oAddRowAct->setText(QString("%1 (%2)").arg(i18n("Add Row"), QString::number(i)));
+		m_oAddColAct->setText(QString("%1 (%2)").arg(i18n("Add Column"), QString::number(j)));
+		m_oRmRowAct->setText(QString("%1 (%2)").arg(i18n("Remove Row"), QString::number(i)));
+		m_oRmColAct->setText(QString("%1 (%2)").arg(i18n("Remove Column"), QString::number(j)));
 
 		QMenu::exec(actions(), i_oEv->globalPos());
 	}
 	else
 	{
 		QTableWidget::mousePressEvent(i_oEv);
+		resizeRowsToContents();
 	}
 }
 
@@ -99,30 +106,30 @@ void table_view::cell_changed(int i_iRow, int i_iCol)
 	if (l_oItem) l_sText = l_oItem->text();
 	else l_sText = "";
 
-	data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+	data_item& l_oData = m_oMediator->m_oItems[m_iId];
 	QHash<QPair<int, int>, QString> changed;
 
 	for (int i=0; i < rowCount(); ++i)
 	{
 		for (int j=0; j < columnCount(); ++j)
 		{
-			changed[QPair<int, int>(i, j)] = l_oData->m_oTableData[QPair<int, int>(i, j)];
+			changed[QPair<int, int>(i, j)] = l_oData.m_oTableData[QPair<int, int>(i, j)];
 		}
 	}
 	changed[QPair<int, int>(i_iRow, i_iCol)] = l_sText;
 
 	mem_table *tmp = new mem_table(m_oMediator);
 	tmp->m_iId = m_iId;
-	tmp->oldNRows = tmp->newNRows = l_oData->m_iNumRows;
-	tmp->oldNCols = tmp->newNCols = l_oData->m_iNumCols;
-	tmp->oldData = l_oData->m_oTableData;
+	tmp->oldNRows = tmp->newNRows = l_oData.m_iNumRows;
+	tmp->oldNCols = tmp->newNCols = l_oData.m_iNumCols;
+	tmp->oldData = l_oData.m_oTableData;
 	tmp->newData = changed;
 	tmp->apply();
 }
 
 void table_view::add_row()
 {
-	data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+	data_item& l_oData = m_oMediator->m_oItems[m_iId];
 	QHash<QPair<int, int>, QString> changed;
 	for (int i=0; i < rowCount() + 1; ++i)
 	{
@@ -131,24 +138,24 @@ void table_view::add_row()
 		for (int j=0; j < columnCount(); ++j)
 		{
 			changed[QPair<int, int>(m_oAddRowAct->row, j)] = "";
-			changed[QPair<int, int>(ii, j)] = l_oData->m_oTableData[QPair<int, int>(i, j)];
+			changed[QPair<int, int>(ii, j)] = l_oData.m_oTableData[QPair<int, int>(i, j)];
 		}
 	}
 
 	mem_table *tmp = new mem_table(m_oMediator);
 	tmp->m_iId = m_iId;
-	tmp->oldNRows = l_oData->m_iNumRows;
-	tmp->oldNCols = l_oData->m_iNumCols;
+	tmp->oldNRows = l_oData.m_iNumRows;
+	tmp->oldNCols = l_oData.m_iNumCols;
 	tmp->newNRows = rowCount() + 1;
 	tmp->newNCols = columnCount();
-	tmp->oldData = l_oData->m_oTableData;
+	tmp->oldData = l_oData.m_oTableData;
 	tmp->newData = changed;
 	tmp->apply();
 }
 
 void table_view::add_column()
 {
-	data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+	data_item& l_oData = m_oMediator->m_oItems[m_iId];
 	QHash<QPair<int, int>, QString> changed;
 	for (int i=0; i < rowCount(); ++i)
 	{
@@ -158,24 +165,24 @@ void table_view::add_column()
 			if (jj >= m_oAddRowAct->col) jj++;
 
 			changed[QPair<int, int>(i, m_oAddRowAct->col)] = "";
-			changed[QPair<int, int>(i, jj)] = l_oData->m_oTableData[QPair<int, int>(i, j)];
+			changed[QPair<int, int>(i, jj)] = l_oData.m_oTableData[QPair<int, int>(i, j)];
 		}
 	}
 
 	mem_table *tmp = new mem_table(m_oMediator);
 	tmp->m_iId = m_iId;
-	tmp->oldNRows = l_oData->m_iNumRows;
-	tmp->oldNCols = l_oData->m_iNumCols;
+	tmp->oldNRows = l_oData.m_iNumRows;
+	tmp->oldNCols = l_oData.m_iNumCols;
 	tmp->newNRows = rowCount();
 	tmp->newNCols = columnCount() + 1;
-	tmp->oldData = l_oData->m_oTableData;
+	tmp->oldData = l_oData.m_oTableData;
 	tmp->newData = changed;
 	tmp->apply();
 }
 
 void table_view::rm_row()
 {
-	data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+	data_item& l_oData = m_oMediator->m_oItems[m_iId];
 	QHash<QPair<int, int>, QString> changed;
 	for (int i=0; i < rowCount(); ++i)
 	{
@@ -184,24 +191,24 @@ void table_view::rm_row()
 		if (ii > m_oRmRowAct->row) ii--;
 		for (int j=0; j < columnCount(); ++j)
 		{
-			changed[QPair<int, int>(ii, j)] = l_oData->m_oTableData[QPair<int, int>(i, j)];
+			changed[QPair<int, int>(ii, j)] = l_oData.m_oTableData[QPair<int, int>(i, j)];
 		}
 	}
 
 	mem_table *tmp = new mem_table(m_oMediator);
 	tmp->m_iId = m_iId;
-	tmp->oldNRows = l_oData->m_iNumRows;
-	tmp->oldNCols = l_oData->m_iNumCols;
+	tmp->oldNRows = l_oData.m_iNumRows;
+	tmp->oldNCols = l_oData.m_iNumCols;
 	tmp->newNRows = rowCount() - 1;
 	tmp->newNCols = columnCount();
-	tmp->oldData = l_oData->m_oTableData;
+	tmp->oldData = l_oData.m_oTableData;
 	tmp->newData = changed;
 	tmp->apply();
 }
 
 void table_view::rm_column()
 {
-	data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+	data_item& l_oData = m_oMediator->m_oItems[m_iId];
 	QHash<QPair<int, int>, QString> changed;
 	for (int i=0; i < rowCount(); ++i)
 	{
@@ -211,17 +218,17 @@ void table_view::rm_column()
 			if (jj == m_oRmRowAct->col) continue;
 			if (jj > m_oAddRowAct->col) jj--;
 
-			changed[QPair<int, int>(i, jj)] = l_oData->m_oTableData[QPair<int, int>(i, j)];
+			changed[QPair<int, int>(i, jj)] = l_oData.m_oTableData[QPair<int, int>(i, j)];
 		}
 	}
 
 	mem_table *tmp = new mem_table(m_oMediator);
 	tmp->m_iId = m_iId;
-	tmp->oldNRows = l_oData->m_iNumRows;
-	tmp->oldNCols = l_oData->m_iNumCols;
+	tmp->oldNRows = l_oData.m_iNumRows;
+	tmp->oldNCols = l_oData.m_iNumCols;
 	tmp->newNRows = rowCount();
 	tmp->newNCols = columnCount() - 1;
-	tmp->oldData = l_oData->m_oTableData;
+	tmp->oldData = l_oData.m_oTableData;
 	tmp->newData = changed;
 	tmp->apply();
 }
@@ -233,14 +240,14 @@ void table_view::resize_table()
 	l_oGen.m_oCols->setValue(columnCount());
 	if (l_oGen.exec() == QDialog::Accepted)
 	{
-		data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+		data_item& l_oData = m_oMediator->m_oItems[m_iId];
 		mem_table *tmp = new mem_table(m_oMediator);
 		tmp->m_iId = m_iId;
-		tmp->oldNRows = l_oData->m_iNumRows;
-		tmp->oldNCols = l_oData->m_iNumCols;
+		tmp->oldNRows = l_oData.m_iNumRows;
+		tmp->oldNCols = l_oData.m_iNumCols;
 		tmp->newNRows = l_oGen.m_oRows->value();
 		tmp->newNCols = l_oGen.m_oCols->value();
-		tmp->oldData = tmp->newData = l_oData->m_oTableData;
+		tmp->oldData = tmp->newData = l_oData.m_oTableData;
 		tmp->apply();
 	}
 }
@@ -253,16 +260,16 @@ void table_view::notify_table(int id)
 	}
 	m_bFreeze = true;
 
-	data_item *l_oData = m_oMediator->m_oItems.value(id);
+	data_item& l_oData = m_oMediator->m_oItems[id];
 
-	if (l_oData->m_iNumRows != rowCount() || l_oData->m_iNumCols != columnCount())
+	if (l_oData.m_iNumRows != rowCount() || l_oData.m_iNumCols != columnCount())
 	{
-		setRowCount(l_oData->m_iNumRows);
-		setColumnCount(l_oData->m_iNumCols);
+		setRowCount(l_oData.m_iNumRows);
+		setColumnCount(l_oData.m_iNumCols);
 	}
 
 	QPair<int, int> t;
-	foreach (t, l_oData->m_oTableData.keys())
+	foreach (t, l_oData.m_oTableData.keys())
 	{
 		QTableWidgetItem *it = item(t.first, t.second);
 		if (!it)
@@ -270,8 +277,9 @@ void table_view::notify_table(int id)
 			it = new QTableWidgetItem();
 			setItem(t.first, t.second, it);
 		}
-		it->setText(l_oData->m_oTableData[t]);
+		it->setText(l_oData.m_oTableData[t]);
 	}
+	resizeRowsToContents();
 	repaint();
 	m_bFreeze = false;
 }
@@ -283,19 +291,18 @@ void table_view::notify_select(const QList<int>& unsel, const QList<int>& sel)
 	bool one = (sel.size() == 1);
 	if (one) {
 		m_iId = sel.at(0);
-		data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+		Q_ASSERT(m_oMediator->m_oItems.contains(m_iId));
+		data_item& l_oData = m_oMediator->m_oItems[m_iId];
 
-		Q_ASSERT(l_oData!=NULL);
-
-		setRowCount(l_oData->m_iNumRows);
-		setColumnCount(l_oData->m_iNumCols);
+		setRowCount(l_oData.m_iNumRows);
+		setColumnCount(l_oData.m_iNumCols);
 
 		for (int i=0; i < rowCount(); ++i)
 		{
 			for (int j=0; j < columnCount(); ++j)
 			{
 				QTableWidgetItem *l_oItem = new QTableWidgetItem();
-				l_oItem->setText(l_oData->m_oTableData[QPair<int, int>(i, j)]);
+				l_oItem->setText(l_oData.m_oTableData[QPair<int, int>(i, j)]);
 				setItem(i, j, l_oItem);
 			}
 		}
@@ -304,9 +311,33 @@ void table_view::notify_select(const QList<int>& unsel, const QList<int>& sel)
 		setRowCount(0);
 		setColumnCount(0);
 	}
+	resizeRowsToContents();
 	repaint();
 	m_bFreeze = false;
 }
 
-#include "table_view.moc"
+table_view_filter::table_view_filter(QWidget* i_oParent): QStyledItemDelegate(i_oParent)
+{
+	m_oParent = dynamic_cast<table_view*>(i_oParent);
+}
+
+QWidget* table_view_filter::createEditor(QWidget *i_oParent, const QStyleOptionViewItem&, const QModelIndex&) const
+{
+	QPlainTextEdit *l_oEditor = new QPlainTextEdit(i_oParent);
+	l_oEditor->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+	l_oEditor->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+	return l_oEditor;
+}
+
+void table_view_filter::setEditorData(QWidget *i_oEditor, const QModelIndex& i_oModelIndex) const
+{
+	QPlainTextEdit *l_oEditor = dynamic_cast<QPlainTextEdit *>(i_oEditor);
+	l_oEditor->setPlainText(i_oModelIndex.data().toString());
+}
+
+void table_view_filter::setModelData(QWidget *i_oEditor, QAbstractItemModel* i_oModel, const QModelIndex& i_oIndex) const
+{
+	QPlainTextEdit* l_oEditor = dynamic_cast<QPlainTextEdit *>(i_oEditor);
+	i_oModel->setData(i_oIndex, l_oEditor->toPlainText());
+}
 
