@@ -1,11 +1,12 @@
 #sem:name: S5 presentation
 #sem:tip: Generates a xhtml presentation using s5
 
-# Thomas Nagy, 2007-2012
+# Thomas Nagy, 2007-2023 GPLV3
 
 import os, shutil, time, getpass
 
 outdir = sembind.get_var('outdir')+'/'+sembind.get_var('pname')
+pygments_css_data = ''
 
 settings = {
 'doc_date':'',
@@ -18,39 +19,24 @@ settings = {
 add_globals(settings)
 
 try:
-	tm = time.strftime('.%d-%b-%y--%H-%M-%S', time.gmtime(os.stat(outdir).st_mtime))
-	os.rename(outdir, outdir+tm)
+	os.makedirs(outdir+'/ui/default/')
 except OSError:
-	pass
-
-try: os.makedirs(outdir+'/ui/default/')
-except OSError: debug('Cannot create folder ' + outdir + '/ui/default/')
+	debug('Cannot create folder ' + outdir + '/ui/default/')
 
 # copy the pictures
-cwd = os.getcwd()
-os.chdir(sembind.get_var('temp_dir'))
-pics = {} # map the id to the picture
-lst = os.listdir('.')
-for x in lst:
-	if x.startswith('diag-') and not x.endswith('pdf'):
-		pics[ x.replace('diag-', '').split('.')[0] ] = x
-		shutil.copy2(x, outdir)
-os.chdir(cwd)
-
+temp_dir = sembind.get_var('temp_dir')
+pics = index_pictures(outdir)
 
 buf = []
 out = buf.append
 
-def p(s):
-	return sembind.protectHTML(s)
-
-def x(s):
+def xml(s):
 	return sembind.protectXML(s)
 
 def print_bullet(node, indent):
 	out('<li>%s</li>\n' % node.get_val('summary'))
 	y = node.get_val('text')
-	out('<div class="handout">%s</div>\n' % p(y))
+	out('<div class="handout">%s</div>\n' % xml(y))
 
 	num = node.child_count()
 	if num:
@@ -63,7 +49,7 @@ def print_slide(node, niv):
 	out('\n\n<div class="slide">\n')
 
 	out('<h1>%s</h1>\n' % node.get_val('summary'))
-	out('<div class="handout">%s</div>\n' % p(node.get_val('text')))
+	out('<div class="handout">%s</div>\n' % xml(node.get_val('text')))
 
 	num = node.child_count()
 	if num:
@@ -77,7 +63,27 @@ def print_slide(node, niv):
 
 def print_figure_slides(node, niv):
 	typo = node.get_val('type')
-	if typo in ['table', 'diag', 'img']:
+	if typo in ['text']:
+		body = parse_raw(node.get_val('text')).strip()
+		lang = node.get_var('code_lang').strip()
+		if body:
+			if lang:
+				html_code = pygmentize(lang, body)
+				global pygments_css_data
+				if not pygments_css_data:
+					pygments_css_data = pygmentize_css()
+				out('\n\n<div class="slide">\n')
+				out('<h1>%s</h1>\n' % node.get_val('summary'))
+				out(html_code)
+				out('</div>')
+			else:
+				debug('For code snippets, set the variable code_lang\n')
+				out('\n\n<div class="slide">\n')
+				out('<h1>%s</h1>\n' % node.get_val('summary'))
+				out(truncate_html(node.get_val('text')))
+				out('</div>')
+
+	elif typo in ['table', 'diag', 'img']:
 
 		out('\n\n<div class="slide">\n')
 		out('<h1>%s</h1>\n' % node.get_val('summary'))
@@ -86,54 +92,39 @@ def print_figure_slides(node, niv):
 			rows = node.num_rows()
 			cols = node.num_cols()
 			if rows>0 and cols>0:
+
+				disable_row_header = node.get_var('disable_row_header', False)
+				disable_col_header = node.get_var('disable_col_header', False)
+
 				out('\n')
 				out('<div style="text-align: center; width: 100%;">\n')
-				out('<table class="sem_table" cellspacing="0px" cellpadding="0px" style="width: 100%;">\n')
+				out('<table class="sem_table">\n')
 				out('<tbody>\n')
 				for i in range(rows):
 					out('\t<tr>\n')
 					for j in range(cols):
-						if i>0 and j>0:
-							out('\t\t<td>%s</td>\n' % x(node.get_cell(i, j)))
+						cell = xml(node.get_cell(i, j)).replace('\n', '<br/>')
+						if (i == 0 and not disable_row_header) or (j == 0 and not disable_col_header):
+							out('\t\t<th>%s</th>\n' % cell)
 						else:
-							out('\t\t<th>%s</th>\n' % x(node.get_cell(i, j)))
+							out('\t\t<td>%s</td>\n' % cell)
 					out('\t</tr>\n')
-		
+
 				out('</tbody>\n')
 				out('</table>\n')
 				out('</div>\n')
 			out('\n')
 
 		elif typo == 'img' or typo == 'diag':
-			id = node.get_val('id')
-			if id in pics:
-
+			the_pic = pics.get(node.get_val('id'))
+			if the_pic and not node.get_var('exclude_pic'):
 				caption = node.get_var('caption')
-				if not caption: caption = caption = node.get_val('summary')
+				if not caption and not node.get_var('disable_caption', False):
+					caption = node.get_val('summary')
 				out('<div style="text-align: center; width: 100%;">\n')
-				out("<img src='%s'>\n" % pics[id])
+				out("<img src='%s' style='max-width:99%%;'>\n" % the_pic)
 				out('</div>\n')
 
-				"""
-				restrict = node.get_var("picdim")
-				if not restrict:
-					w = int(node.get_val('pic_w'))
-					restrict = ""
-					if (w > 5*72): restrict = "[width=5in]"
-				if not restrict:
-					restrict = "[width=\\textwidth,height=\\textheight,keepaspectratio]"
-
-				out('\\begin{figure}[htbp]\n')
-				out('  \\begin{center}\n')
-				out('    \\includegraphics%s{%s}\n' % (restrict, pics[id]))
-				out('    \\caption{\\footnotesize{%s}}\n' % tex_convert(caption))
-				out('%% %s\n' % protect_tex(node.get_val('pic_location')))
-				out('%% %s\n' % node.get_val('pic_w'))
-				out('%% %s\n' % node.get_val('pic_h'))
-				out('    \\end{center}\n')
-				out('\\end{figure}\n')
-				"""
-
 		out("</div>\n")
 
 	num = node.child_count()
@@ -158,7 +149,7 @@ def print_nodes(node, niv):
 		if not node.get_var('skip_slide'):
 			out('\n\n<div class="slide">\n')
 			out('<h1>%s</h1>\n' % node.get_val('summary'))
-			out('<div class="handout">%s</div>\n' % p(node.get_val('text')))
+			out('<div class="handout">%s</div>\n' % xml(node.get_val('text')))
 
 			# print the main titles
 			num = node.child_count()
@@ -203,6 +194,8 @@ shutil.copy2(template_dir()+'/s5/ui/default/blank.gif', outdir+'/ui/default/')
 for x in files_lst:
 	transform('/s5/ui/default/'+x, outdir+'/ui/default/'+x, settings)
 
+with open(outdir + '/ui/default/pygments.css', 'w') as f:
+	f.write(pygments_css_data)
+
 visualize('s5', outdir+'/index.html')
 
-
