@@ -1,26 +1,28 @@
 #sem:name: semantik document generator
 #sem:tip: used for saving semantik documents
 
-# Thomas Nagy, 2007-2012
+# Thomas Nagy, 2007-2023 GPLV3
 
 import os, tarfile
-from cStringIO import StringIO
+import io
 
 tar = tarfile.open(sembind.get_var('outfile'), 'w:gz')
 
-doc = sembind.get_var('fulldoc')
-stuff = StringIO(doc)
+doc = sembind.get_var('fulldoc').encode('utf-8')
+stuff = io.BytesIO(doc)
 tarinfo = tarfile.TarInfo('con.xml')
 tarinfo.size = len(doc)
 tar.addfile(tarinfo, stuff)
 
-#debug(doc.encode('utf-8'))
+#debug(doc)
 
-os.chdir(sembind.get_var('temp_dir'))
-lst = os.listdir('.')
+temp_dir = sembind.get_var('temp_dir')
+lst = os.listdir(temp_dir)
 
 tmp = str(sembind.get_item_ids()).split(",")
 for x in tmp:
+	if not x:
+		continue
 	item = sembind.get_item_by_id(int(x))
 	if item:
 		pid = sembind.get_val(item, "pic_id")
@@ -28,7 +30,7 @@ for x in tmp:
 		if pid != '0':
 			for pic in lst:
 				if pic.startswith(s):
-					tar.add(pic, pic)
+					tar.add(os.path.join(temp_dir, pic), pic)
 					break
 			else:
 				debug("Could not find the picture for item %r->%r in %r" % (x, pid, sembind.get_var('temp_dir')))
