@@ -1,4 +1,4 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #include <QtDebug>
 #include <QTextEdit>
@@ -13,6 +13,7 @@
 #include "data_item.h"
 #include "sem_mediator.h"
 #include "vars_view.h"
+#include "mem_command.h"
 
 vars_view::vars_view(QWidget *i_oParent, sem_mediator *i_oControl) : QTextEdit(i_oParent)
 {
@@ -33,8 +34,9 @@ void vars_view::init_completer()
 	QTreeView *l_oTreeView = NULL;
 
 	QStandardItemModel *l_oModelItem = new QStandardItemModel(this);
-
 	fillloc(l_oModelItem);
+	l_oModelItem->sort(0);
+
 	l_oTreeView = new QTreeView;
 	m_oCompleterItem->setPopup(l_oTreeView);
 	m_oCompleterItem->setModel(l_oModelItem);
@@ -44,8 +46,8 @@ void vars_view::init_completer()
 	m_oCompleterItem->setCaseSensitivity(Qt::CaseInsensitive);
 	l_oTreeView->header()->hide();
 	l_oTreeView->header()->setStretchLastSection(false);
-	l_oTreeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
-	l_oTreeView->header()->setResizeMode(1, QHeaderView::Stretch);
+	l_oTreeView->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
+	l_oTreeView->header()->setSectionResizeMode(1, QHeaderView::Stretch);
 	l_oTreeView->setRootIsDecorated(false);
 	QObject::connect(m_oCompleterItem, SIGNAL(activated(const QString&)), this, SLOT(do_complete(const QString&)));
 
@@ -53,6 +55,7 @@ void vars_view::init_completer()
 
 	QStandardItemModel *l_oModelAll = new QStandardItemModel(this);
 	fillglo(l_oModelAll)
+	l_oModelAll->sort(0);
 
 
 	l_oTreeView = new QTreeView;
@@ -63,8 +66,8 @@ void vars_view::init_completer()
 	m_oCompleterAll->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
 	m_oCompleterAll->setCaseSensitivity(Qt::CaseInsensitive);
 	l_oTreeView->header()->setStretchLastSection(false);
-	l_oTreeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
-	l_oTreeView->header()->setResizeMode(1, QHeaderView::Stretch);
+	l_oTreeView->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
+	l_oTreeView->header()->setSectionResizeMode(1, QHeaderView::Stretch);
 	l_oTreeView->setRootIsDecorated(false);
 	l_oTreeView->header()->hide();
 	QObject::connect(m_oCompleterAll, SIGNAL(activated(const QString&)), this, SLOT(do_complete(const QString&)));
@@ -73,8 +76,8 @@ void vars_view::init_completer()
 	// initialize
 	m_oCompleter = m_oCompleterAll;
 
-	m_oCompleteAction = new QAction(trUtf8("Code complete"), this);
-	m_oCompleteAction->setShortcut(trUtf8("Ctrl+space"));
+	m_oCompleteAction = new QAction(i18n("Code complete"), this);
+	m_oCompleteAction->setShortcut(i18n("Ctrl+space"));
 	connect(m_oCompleteAction, SIGNAL(triggered()), this, SLOT(try_complete()));
 	addAction(m_oCompleteAction);
 
@@ -89,13 +92,18 @@ void vars_view::init_completer()
 void vars_view::notify_vars(int id) {
 	if (id == m_iId) {
 		m_bLockEdit = true;
+
+		QString text;
 		if (id != NO_ITEM) {
-			data_item *sel = *m_oMediator + id;
-			setText(sel->m_sHints);
+			data_item& sel = *m_oMediator + id;
+			text = sel.m_sHints;
 		}
 		else
 		{
-			setText(m_oMediator->m_sHints);
+			text = m_oMediator->m_sHints;
+		}
+		if (text != toPlainText()) {
+			setText(text);
 		}
 		m_bLockEdit = false;
 	}
@@ -106,9 +114,9 @@ void vars_view::notify_select(const QList<int>& unsel, const QList<int>& sel) {
 	m_bLockEdit = true;
 	if (one) {
 		m_iId = sel.at(0);
-		data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
+		data_item& l_oData = m_oMediator->m_oItems[m_iId];
 		m_oCompleter = m_oCompleterItem;
-		setText(l_oData->m_sHints);
+		setText(l_oData.m_sHints);
 	} else {
 		m_iId = NO_ITEM;
 		m_oCompleter = m_oCompleterAll;
@@ -147,8 +155,8 @@ void vars_view::update_edit()
 		tmp->m_iId = m_iId;
 		if (m_iId)
 		{
-			data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
-			tmp->oldVars = l_oData->m_sHints;
+			data_item& l_oData = m_oMediator->m_oItems[m_iId];
+			tmp->oldVars = l_oData.m_sHints;
 		}
 		else
 		{
@@ -157,11 +165,12 @@ void vars_view::update_edit()
 		tmp->add();
 	}
 	tmp->newVars = toPlainText();
+	tmp->apply();
 
 	if (m_iId)
 	{
-		data_item *l_oData = m_oMediator->m_oItems.value(m_iId);
-		l_oData->m_sHints = tmp->newVars;
+		data_item& l_oData = m_oMediator->m_oItems[m_iId];
+		l_oData.m_sHints = tmp->newVars;
 	}
 	else
 	{
@@ -307,5 +316,9 @@ void vars_view::try_complete()
 	m_oCompleter->complete(l_oRect);
 }
 
-#include "vars_view.moc"
-
+void vars_view::notify_open_map()
+{
+	m_iId = NO_ITEM;
+	m_oCompleter = m_oCompleterAll;
+	setText(m_oMediator->m_sHints);
+}
