@@ -1,13 +1,15 @@
-// Thomas Nagy 2007-2012 GPLV3
+// Thomas Nagy 2007-2023 GPLV3
 
 #ifndef VARS_VIEW_H
 #define VARS_VIEW_H
 
 #include <QList>
 #include <QTreeWidget>
+#include <QTextEdit>
 #include <QSyntaxHighlighter>
 
 class QCompleter;
+class sem_mediator;
 class class_rule
 {
 	public:
@@ -45,6 +47,7 @@ class vars_view : public QTextEdit
 		void try_complete();
 		void notify_select(const QList<int>& unsel, const QList<int>& sel);
 		void notify_vars(int);
+		void notify_open_map();
 };
 
 #endif
